format zx81
;labelusenumeric
;LISTOFF

	// hardware options to be set and change defaults in ZX81DEF.INC
	MEMAVL	   =	   MEM_16K	   // can be MEM_1K, MEM_2K, MEM_4K, MEM_8K, MEM_16K, MEM_32K, MEM_48K
					   // default value is MEM_16K
	STARTMODE  EQU	   SLOW_MODE	   // SLOW or FAST
	DFILETYPE  EQU	   COLLAPSED	   // COLLAPSED or EXPANDED or AUTO
	STARTUPMSG EQU	  'CREATED WITH ZX81-IDE' // any message will be shown on screen after loading, max. 32 chars

	include 'SINCL-ZX\ZX81.INC'	   // definitions of constants

;LISTON



	REM _hide _noedit  _asm

start:
	;test code

	call	$0f23		;FAST
	ld hl,music_data
	call play
	call	$0f2b		;SLOW
	ret


	;engine code

;squat by Shiru, 06'17
;Squeeker like, just without the output value table
;4 channels of tone with different duty cycle
;sample drums, non-interrupting
;customizeable noise percussion, interrupting


;music data is all 16-bit words, first control then a few optional ones

;control word is PSSSSSSS DDDN4321, where P=percussion,S=speed, D=drum, N=noise mode, 4321=channels
;D triggers non-interruping sample drum
;P trigger
;if 1, channel 1 freq follows
;if 2, channel 2 freq follows
;if 3, channel 3 freq follows
;if 4, channel 4 freq follows
;if N, channel 4 mode follows, it is either $0000 (normal) or $04cb (noise)
;if P, percussion follows, LSB=volume, MSB=pitch



RLC_H=$04cb		;to enable noise mode
NOP_2=$0000		;to disable noise mode
RLC_HL=$06cb		;to enable sample reading
ADD_IX_IX=$29dd 	;to disable sample reading


play:

;        di

	ld e,(hl)
	inc hl
	ld d,(hl)
	inc hl
	ld (pattern_ptr),de
	
	ld e,(hl)
	inc hl
	ld d,(hl)
	
	ld (loop_ptr),de

	dec hl
	ld (sample_list),hl
	
	ld hl,ADD_IX_IX
	ld (sample_read),hl
	ld hl,NOP_2				;normal mode
	ld (noise_mode),hl
	
	ld ix,0 				;needs to be 0 to skip sample reading

	ld c,0
	exx
	ld de,$0808				;sample bit counter and reload value

play_loop:

pattern_ptr=$+1
	ld sp,0
	
return_loop:

	pop bc					;control word
						;B=duration of the row (0=loop)
						;C=flags DDDN4321 (Drum, Noise, 1-4 channel update)
	ld a,b
	or a
	jp nz,no_loop
	
loop_ptr=$+1
	ld sp,0
	
	jp return_loop
	
no_loop:

	ld a,c
	
	rra
	jr nc,skip_note_0
	
	pop hl
	ld (ch0_add),hl
	
skip_note_0:

	rra
	jr nc,skip_note_1

	pop hl
	ld (ch1_add),hl
	
skip_note_1:

	rra
	jr nc,skip_note_2
	
	pop hl
	ld (ch2_add),hl
	
skip_note_2:

	rra
	jr nc,skip_note_3
	
	pop hl
	ld (ch3_add),hl
	
skip_note_3:

	rra
	jr nc,skip_mode_change
	
	pop hl					;nop:nop or rlc h
	ld (noise_mode),hl

skip_mode_change:

	and 7
	jp z,skip_drum
	
sample_list=$+1
	ld hl,0 				;sample_list-2
	add a,a
	add a,l
	ld l,a
	ld a,(hl)
	inc l
	ld h,(hl)
	ld l,a
	ld (sample_ptr),hl
	ld hl,RLC_HL
	ld (sample_read),hl

skip_drum:

	bit 7,b 				;check percussion flag
	jp z,skip_percussion

	res 7,b 				;clear percussion flag
	dec b					;compensate speed

	ld (noise_bc),bc
	ld (noise_de),de

	pop hl					;read percussion parameters

	ld a,l					;noise volume
	ld (noise_volume),a
	ld b,h					;noise pitch
	ld c,h
	ld de,$2174				;utz's rand seed			
	exx
	ld bc,811				;noise duration, takes as long as inner sound loop

noise_loop:

	exx				;4
	dec c				;4
	jr nz,noise_skip		;7/12
	ld c,b				;4
	add hl,de			;11
	rlc h				;8	utz's noise generator idea
	inc d				;4	improves randomness
	jp noise_next			;10
	
noise_skip:

	jr $+2				;12
	jr $+2				;12
	nop				;4
	nop				;4
	
noise_next:

	ld a,h				;4
	
noise_volume=$+1
	cp $80				;7
;        sbc a,a                         ;4
;        out ($fe),a                     ;11

	jp c,.HP	;[10]

	in a,($fe)	;[11]
	jp .LP		;[10]

.HP:	out ($ff),a	;[11]
	jp .LP		;[10]
.LP:
	exx				;4

	dec bc				;6
	ld a,b				;4
	or c				;4
	jp nz,noise_loop		;10=106t

	exx

noise_bc=$+1
	ld bc,0
noise_de=$+1
	ld de,0



skip_percussion:

	ld (pattern_ptr),sp

sample_ptr=$+1
	ld hl,0

	ld c,0					;internal loop runs 256 times

sound_loop:

sample_read=$
	rlc (hl)			;15	rotate sample bits in place, rl (hl) or add ix,ix (dummy operation)
	sbc a,a 			;4	sbc a,a to make bit into 0 or 255, or xor a to keep it 0

	dec e				;4--+	count bits
	jp z,sample_cycle		;10 |
	jp sample_next			;10

sample_cycle:

	ld e,d				;4  |	reload counter
	inc hl				;6--+	advance pointer --24t

sample_next:

	exx				;4	squeeker type unrolled code
	ld b,a				;4	sample mask
	xor a				;4
	
	ld sp,sound_list		;10
		
	pop de				;10	ch0_acc
	pop hl				;10	ch0_add
	add hl,de			;11
	rla				;4
	ld (ch0_acc),hl 		;16
						
	pop de				;10	ch1_acc
	pop hl				;10	ch1_add
	add hl,de			;11
	rla				;4
	ld (ch1_acc),hl 		;16
	
	pop de				;10	ch2_acc
	pop hl				;10	ch2_add
	add hl,de			;11
	rla							;4
	ld (ch2_acc),hl 		;16

	pop de				;10	ch3_acc
	pop hl				;10	ch3_add
	add hl,de			;11
	
noise_mode=$
;        ds 2,0                          ;8      rlc h for noise effects
	rb 2

	rla				;4
	ld (ch3_acc),hl 		;16

	add a,c 			;4	no table like in Squeeker, channels summed as is, for uneven 'volume'
	add a,$ff			;7
	sbc a,$ff			;7
	ld c,a				;4
	sbc a,a 			;4

	or b				;4	mix sample
	
;        out ($fe),a                     ;11

	and $10 	;[7]
	jp nz,.HP	;[10]

	in a,($fe)	;[11]
	jp .LP		;[10]

.HP:	out ($ff),a	;[11]
	jp .LP		;[10]
.LP:

	exx				;4

	dec c				;4
	jp nz,sound_loop		;10=374  ;336t


	dec hl					;last byte of a 256/8 byte sample packet is $80 means it was the last packet
	ld a,(hl)
	inc hl
	cp $80
	jr nz,sample_no_stop

	ld hl,ADD_IX_IX
	ld (sample_read),hl			;disable sample reading

sample_no_stop:

	djnz sound_loop

	ld (sample_ptr),hl
	
	jp play_loop
	

;variables in the sound_list can't be reordered because of stack-based fetching

sound_list:

ch0_add 	dw 0
ch0_acc 	dw 0
ch1_add 	dw 0
ch1_acc 	dw 0
ch2_add 	dw 0
ch2_acc 	dw 0
ch3_add 	dw 0
ch3_acc 	dw 0


;compiled music data

	align 2

music_data:
	dw .pattern
	dw .loop
;sample data

.sample_list:
	dw .sample_1
	dw .sample_2
	dw .sample_3
	dw .sample_4
	dw .sample_5
	dw .sample_6
	dw .sample_7
	align 256/8

.sample_1:
	db 4,4,114,125,1,68,0,0,0,0,248,255,255,255,255,255
	db 1,0,0,0,0,0,0,0,0,0,255,255,255,255,255,128
.sample_2:
	db 62,1,144,127,240,2,0,0,248,255,3,0,0,162,255,55
	db 0,0,128,252,127,4,0,0,252,63,6,0,0,64,68,128
.sample_3:
	db 0,7,47,1,0,0,0,2,0,8,0,0,0,0,0,0
	db 0,0,0,0,64,64,0,0,0,0,0,0,0,0,0,128
.sample_4:
.sample_5:
.sample_6:
.sample_7:


.pattern:
	dw $21f,$0,$67b,$0,$0,NOP_2
	dw $202,$0
	dw $200
	dw $200
	dw $207,$19e,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $206,$cf6,$7b5
	dw $206,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $20f,$19e,$b8c,$cf6,$196
	dw $20f,$0,$0,$0,$0
	dw $208,$196
	dw $208,$0
	dw $206,$67b,$b8c
	dw $206,$0,$0
	dw $208,$196
	dw $208,$0
	dw $20f,$19e,$7b5,$67b,$196
	dw $20f,$0,$0,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $206,$9b5,$7b5
	dw $206,$0,$0
	dw $208,$196
	dw $208,$0
	dw $20e,$7b5,$9b5,$196
	dw $20e,$0,$0,$0
	dw $200
	dw $200
	dw $206,$67b,$7b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$171,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$171
	dw $201,$0
	dw $20e,$cf6,$7b5,$169
	dw $20e,$0,$0,$0
	dw $209,$171,$169
	dw $209,$0,$0
	dw $20f,$171,$b8c,$cf6,$7b5
	dw $20f,$0,$0,$0,$0
	dw $208,$169
	dw $208,$0
	dw $20e,$67b,$b8c,$169
	dw $20e,$0,$0,$0
	dw $208,$7b5
	dw $208,$0
	dw $207,$171,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$171
	dw $201,$0
	dw $20e,$9b5,$7b5,$7b5
	dw $20e,$0,$0,$0
	dw $208,$169
	dw $208,$0
	dw $206,$7b5,$9b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $206,$67b,$7b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$229,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$229
	dw $201,$0
	dw $20e,$cf6,$7b5,$221
	dw $20e,$0,$0,$0
	dw $209,$229,$221
	dw $209,$0,$0
	dw $207,$229,$b8c,$cf6
	dw $207,$0,$0,$0
	dw $208,$221
	dw $208,$0
	dw $20e,$67b,$b8c,$221
	dw $20e,$0,$0,$0
	dw $200
	dw $200
	dw $207,$229,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$229
	dw $201,$0
	dw $20e,$9b5,$7b5,$221
	dw $20e,$0,$0,$0
	dw $208,$221
	dw $208,$0
	dw $206,$7b5,$9b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $206,$67b,$7b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$229,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$229
	dw $201,$0
	dw $20e,$cf6,$7b5,$221
	dw $20e,$0,$0,$0
	dw $209,$229,$221
	dw $209,$0,$0
	dw $207,$229,$b8c,$cf6
	dw $207,$0,$0,$0
	dw $208,$221
	dw $208,$0
	dw $20a,$67b,$cee
	dw $20a,$0,$0
	dw $20a,$67b,$ce6
	dw $20a,$0,$0
	dw $20f,$229,$7b5,$67b,$f62
	dw $20f,$0,$0,$0,$0
	dw $20f,$229,$7b5,$67b,$f5a
	dw $20f,$0,$0,$0,$0
	dw $20e,$cf6,$7b5,$19e4
	dw $20e,$0,$0,$0
	dw $20e,$cf6,$7b5,$19dc
	dw $20e,$0,$0,$0
	dw $20e,$b8c,$cf6,$1710
	dw $20e,$0,$0,$0
	dw $20e,$b8c,$cf6,$1708
	dw $20e,$0,$0,$0
	dw $226,$67b,$7b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$19e,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $22e,$cf6,$7b5,$196
	dw $20e,$0,$0,$0
	dw $209,$19e,$196
	dw $209,$0,$0
	dw $207,$19e,$b8c,$cf6
	dw $207,$0,$0,$0
	dw $208,$196
	dw $208,$0
	dw $22e,$67b,$b8c,$196
	dw $20e,$0,$0,$0
	dw $200
	dw $200
	dw $207,$19e,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $22e,$9b5,$7b5,$196
	dw $20e,$0,$0,$0
	dw $208,$196
	dw $208,$0
	dw $206,$7b5,$9b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $226,$67b,$7b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$171,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$171
	dw $201,$0
	dw $22e,$cf6,$7b5,$169
	dw $20e,$0,$0,$0
	dw $209,$171,$169
	dw $209,$0,$0
	dw $20f,$171,$b8c,$cf6,$7b5
	dw $20f,$0,$0,$0,$0
	dw $208,$169
	dw $208,$0
	dw $22e,$67b,$b8c,$169
	dw $20e,$0,$0,$0
	dw $208,$7b5
	dw $208,$0
	dw $207,$171,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$171
	dw $201,$0
	dw $22e,$9b5,$7b5,$7b5
	dw $20e,$0,$0,$0
	dw $228,$169
	dw $208,$0
	dw $226,$7b5,$9b5
	dw $206,$0,$0
	dw $220
	dw $200
	dw $226,$67b,$7b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$229,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$229
	dw $201,$0
	dw $22e,$cf6,$7b5,$221
	dw $20e,$0,$0,$0
	dw $209,$229,$221
	dw $209,$0,$0
	dw $207,$229,$b8c,$cf6
	dw $207,$0,$0,$0
	dw $208,$221
	dw $208,$0
	dw $22e,$67b,$b8c,$221
	dw $20e,$0,$0,$0
	dw $200
	dw $200
	dw $207,$229,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$229
	dw $201,$0
	dw $22e,$9b5,$7b5,$221
	dw $20e,$0,$0,$0
	dw $208,$221
	dw $208,$0
	dw $206,$7b5,$9b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $226,$67b,$7b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$229,$7b5,$67b
	dw $207,$0,$0,$0
	dw $201,$229
	dw $201,$0
	dw $22e,$cf6,$7b5,$221
	dw $20e,$0,$0,$0
	dw $208,$221
	dw $208,$0
	dw $20f,$114,$b8c,$cf6,$104
	dw $20f,$0,$0,$0,$0
	dw $209,$114,$104
	dw $209,$0,$0
	dw $22f,$229,$b8c,$67b,$219
	dw $206,$0,$0
	dw $204,$67b
	dw $20d,$0,$0,$0
	dw $20f,$229,$67b,$7b5,$b8c
	dw $20e,$0,$0,$0
	dw $204,$7b5
	dw $205,$0,$0
	dw $24f,$229,$cf6,$ce6,$67b
	dw $20e,$0,$0,$0
	dw $246,$cf6,$ce6
	dw $206,$0,$0
	dw $24e,$cf6,$b7c,$7b5
	dw $24e,$0,$0,$0
	dw $247,$0,$cf6,$b7c
	dw $246,$0,$0
	dw $227,$19e,$67b,$7b5
	dw $207,$0,$0,$0
	dw $8205,$19e,$7b5,$1110
	dw $204,$0
	dw $26f,$33d,$7b5,$67b,$7b5
	dw $20e,$0,$0,$0
	dw $8208,$7b5,$1110
	dw $208,$0
	dw $247,$19e,$cf6,$7b5
	dw $207,$0,$0,$0
	dw $8201,$19e,$f10
	dw $200
	dw $26f,$33d,$b8c,$cf6,$7b5
	dw $20e,$0,$0,$0
	dw $8268,$7b5,$1110
	dw $208,$0
	dw $20f,$19e,$67b,$b8c,$7b5
	dw $20f,$0,$0,$0,$0
	dw $8261,$19e,$f10
	dw $200
	dw $227,$33d,$7b5,$67b
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $247,$19e,$9b5,$7b5
	dw $207,$0,$0,$0
	dw $8201,$19e,$d10
	dw $200
	dw $267,$33d,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $227,$171,$67b,$746
	dw $207,$0,$0,$0
	dw $8205,$171,$746,$d10
	dw $204,$0
	dw $22f,$2e3,$7b5,$67b,$746
	dw $20e,$0,$0,$0
	dw $8208,$746,$d10
	dw $208,$0
	dw $247,$171,$cf6,$7b5
	dw $207,$0,$0,$0
	dw $8201,$171,$b10
	dw $200
	dw $26f,$2e3,$b8c,$cf6,$746
	dw $20e,$0,$0,$0
	dw $8268,$746,$d10
	dw $208,$0
	dw $20f,$171,$67b,$b8c,$746
	dw $20f,$0,$0,$0,$0
	dw $8241,$171,$b10
	dw $200
	dw $227,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8200,$b10
	dw $200
	dw $247,$171,$9b5,$7b5
	dw $207,$0,$0,$0
	dw $8201,$171,$910
	dw $200
	dw $247,$2e3,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$b10
	dw $200
	dw $227,$114,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8205,$114,$b8c,$910
	dw $204,$0
	dw $26f,$229,$7b5,$67b,$746
	dw $20e,$0,$0,$0
	dw $8208,$746,$910
	dw $208,$0
	dw $247,$114,$cf6,$7b5
	dw $207,$0,$0,$0
	dw $8201,$114,$710
	dw $200
	dw $26f,$229,$b8c,$cf6,$746
	dw $20e,$0,$0,$0
	dw $8268,$746,$910
	dw $208,$0
	dw $20f,$114,$67b,$b8c,$746
	dw $20f,$0,$0,$0,$0
	dw $8261,$114,$710
	dw $200
	dw $227,$229,$7b5,$67b
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $247,$114,$9b5,$7b5
	dw $207,$0,$0,$0
	dw $8201,$114,$510
	dw $200
	dw $267,$229,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $227,$114,$67b,$cf6
	dw $207,$0,$0,$0
	dw $8205,$114,$cf6,$510
	dw $204,$0
	dw $22f,$229,$7b5,$67b,$7b5
	dw $20e,$0,$0,$0
	dw $8208,$7b5,$510
	dw $208,$0
	dw $247,$114,$cf6,$7b5
	dw $207,$0,$0,$0
	dw $8201,$114,$310
	dw $200
	dw $26f,$229,$b8c,$cf6,$7b5
	dw $20e,$0,$0,$0
	dw $8248,$7b5,$510
	dw $208,$0
	dw $22f,$114,$67b,$b8c,$7b5
	dw $20f,$0,$0,$0,$0
	dw $8241,$114,$310
	dw $200
	dw $227,$229,$7b5,$67b
	dw $206,$0,$0
	dw $8200,$310
	dw $200
	dw $247,$114,$9b5,$7b5
	dw $207,$0,$0,$0
	dw $8221,$114,$510
	dw $200
	dw $247,$229,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$310
	dw $200
	dw $227,$19e,$67b,$7b5
	dw $207,$0,$0,$0
	dw $8205,$19e,$7b5,$310
	dw $204,$0
	dw $26f,$33d,$7b5,$67b,$7b5
	dw $20e,$0,$0,$0
	dw $8208,$7b5,$310
	dw $208,$0
	dw $247,$19e,$cf6,$7b5
	dw $207,$0,$0,$0
	dw $8201,$19e,$510
	dw $200
	dw $26f,$33d,$b8c,$cf6,$7b5
	dw $20e,$0,$0,$0
	dw $8268,$7b5,$310
	dw $208,$0
	dw $20f,$19e,$67b,$b8c,$7b5
	dw $20f,$0,$0,$0,$0
	dw $8261,$19e,$510
	dw $200
	dw $227,$33d,$7b5,$67b
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $247,$19e,$9b5,$7b5
	dw $207,$0,$0,$0
	dw $8201,$19e,$710
	dw $200
	dw $267,$33d,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $227,$1ed,$67b,$746
	dw $207,$0,$0,$0
	dw $8205,$1ed,$746,$710
	dw $204,$0
	dw $22f,$3da,$7b5,$67b,$746
	dw $20e,$0,$0,$0
	dw $8208,$746,$710
	dw $208,$0
	dw $247,$1ed,$cf6,$7b5
	dw $207,$0,$0,$0
	dw $8201,$1ed,$910
	dw $200
	dw $26f,$3da,$b8c,$cf6,$746
	dw $20e,$0,$0,$0
	dw $8268,$746,$710
	dw $208,$0
	dw $20f,$1ed,$67b,$b8c,$746
	dw $20f,$0,$0,$0,$0
	dw $8241,$1ed,$910
	dw $200
	dw $227,$3da,$7b5,$67b
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $247,$1ed,$9b5,$7b5
	dw $207,$0,$0,$0
	dw $8201,$1ed,$b10
	dw $200
	dw $247,$3da,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$910
	dw $200
	dw $227,$171,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8205,$171,$b8c,$b10
	dw $204,$0
	dw $26f,$2e3,$7b5,$67b,$746
	dw $20e,$0,$0,$0
	dw $8208,$746,$b10
	dw $208,$0
	dw $247,$171,$cf6,$7b5
	dw $207,$0,$0,$0
	dw $8201,$171,$d10
	dw $200
	dw $26f,$2e3,$b8c,$cf6,$746
	dw $20e,$0,$0,$0
	dw $8268,$746,$b10
	dw $208,$0
	dw $20f,$171,$67b,$b8c,$746
	dw $20f,$0,$0,$0,$0
	dw $8261,$171,$d10
	dw $200
	dw $227,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $247,$171,$9b5,$7b5
	dw $207,$0,$0,$0
	dw $8201,$171,$f10
	dw $200
	dw $267,$2e3,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $227,$171,$67b,$cf6
	dw $207,$0,$0,$0
	dw $8205,$171,$cf6,$f10
	dw $204,$0
	dw $22f,$2e3,$7b5,$67b,$7b5
	dw $20e,$0,$0,$0
	dw $8208,$7b5,$f10
	dw $208,$0
	dw $247,$171,$cf6,$7b5
	dw $207,$0,$0,$0
	dw $8201,$171,$1110
	dw $200
	dw $26f,$2e3,$b8c,$cf6,$7b5
	dw $20e,$0,$0,$0
	dw $8248,$7b5,$f10
	dw $208,$0
	dw $22f,$171,$67b,$b8c,$7b5
	dw $20f,$0,$0,$0,$0
	dw $8241,$171,$1110
	dw $200
	dw $227,$2e3,$7b5,$67b
	dw $207,$0,$0,$0
	dw $8201,$2e3,$1110
	dw $201,$0
	dw $247,$2e3,$9b5,$7b5
	dw $207,$0,$0,$0
	dw $8221,$2e3,$f10
	dw $201,$0
	dw $247,$2e3,$7b5,$9b5
	dw $207,$0,$0,$0
	dw $8241,$2e3,$1110
	dw $201,$0
	dw $227,$19e,$67b,$7b5
	dw $203,$0,$0
	dw $8205,$19e,$0,$1110
	dw $200
	dw $267,$33d,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$7b5,$1110
	dw $200
	dw $24f,$19e,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$19e,$f10
	dw $200
	dw $26f,$33d,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8268,$0,$1110
	dw $200
	dw $207,$19e,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8269,$19e,$f6a,$f10
	dw $200
	dw $22f,$33d,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $24f,$19e,$9b5,$7b5,$e8c
	dw $207,$0,$0,$0
	dw $8209,$19e,$0,$d10
	dw $200
	dw $267,$33d,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $227,$171,$67b,$b8c
	dw $203,$0,$0
	dw $8205,$171,$0,$d10
	dw $200
	dw $227,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$b8c,$d10
	dw $200
	dw $24f,$171,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$171,$b10
	dw $200
	dw $26f,$2e3,$b8c,$cf6,$114d
	dw $206,$0,$0
	dw $8268,$0,$d10
	dw $200
	dw $207,$171,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8249,$171,$114d,$b10
	dw $200
	dw $22f,$2e3,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$b10
	dw $200
	dw $24f,$171,$9b5,$7b5,$8a6
	dw $207,$0,$0,$0
	dw $8209,$171,$0,$910
	dw $200
	dw $247,$2e3,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$b10
	dw $200
	dw $227,$114,$67b,$746
	dw $203,$0,$0
	dw $8205,$114,$0,$910
	dw $200
	dw $267,$229,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$746,$910
	dw $200
	dw $24f,$114,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$114,$710
	dw $200
	dw $26f,$229,$b8c,$cf6,$e8c
	dw $206,$0,$0
	dw $8268,$0,$910
	dw $200
	dw $207,$114,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8269,$114,$e8c,$710
	dw $200
	dw $22f,$229,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $24f,$114,$9b5,$7b5,$b8c
	dw $207,$0,$0,$0
	dw $8209,$114,$0,$510
	dw $200
	dw $267,$229,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $227,$114,$67b,$cf6
	dw $203,$0,$0
	dw $8205,$114,$0,$510
	dw $200
	dw $227,$229,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$cf6,$510
	dw $200
	dw $24f,$114,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$114,$310
	dw $200
	dw $26f,$229,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8248,$0,$510
	dw $200
	dw $227,$114,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8249,$114,$f6a,$310
	dw $200
	dw $22f,$229,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$310
	dw $200
	dw $24f,$114,$9b5,$7b5,$8a6
	dw $207,$0,$0,$0
	dw $8229,$114,$0,$510
	dw $200
	dw $247,$229,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$310
	dw $200
	dw $227,$19e,$67b,$7b5
	dw $203,$0,$0
	dw $8205,$19e,$0,$310
	dw $200
	dw $267,$33d,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$7b5,$310
	dw $200
	dw $24f,$19e,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$19e,$510
	dw $200
	dw $26f,$33d,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8268,$0,$310
	dw $200
	dw $207,$19e,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8269,$19e,$f6a,$510
	dw $200
	dw $22f,$33d,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $24f,$19e,$9b5,$7b5,$e8c
	dw $207,$0,$0,$0
	dw $8209,$19e,$0,$710
	dw $200
	dw $267,$33d,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $227,$1ed,$67b,$b8c
	dw $203,$0,$0
	dw $8205,$1ed,$0,$710
	dw $200
	dw $227,$3da,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$b8c,$710
	dw $200
	dw $24f,$1ed,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$1ed,$910
	dw $200
	dw $26f,$3da,$b8c,$cf6,$114d
	dw $206,$0,$0
	dw $8268,$0,$710
	dw $200
	dw $207,$1ed,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8249,$1ed,$114d,$910
	dw $200
	dw $22f,$3da,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $24f,$1ed,$9b5,$7b5,$8a6
	dw $207,$0,$0,$0
	dw $8209,$1ed,$0,$b10
	dw $200
	dw $247,$3da,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$910
	dw $200
	dw $227,$171,$67b,$746
	dw $203,$0,$0
	dw $8205,$171,$0,$b10
	dw $200
	dw $267,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$746,$b10
	dw $200
	dw $24f,$171,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$171,$d10
	dw $200
	dw $26f,$2e3,$b8c,$cf6,$e8c
	dw $206,$0,$0
	dw $8268,$0,$b10
	dw $200
	dw $207,$171,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8269,$171,$e8c,$d10
	dw $200
	dw $22f,$2e3,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $24f,$171,$9b5,$7b5,$b8c
	dw $207,$0,$0,$0
	dw $8209,$171,$0,$f10
	dw $200
	dw $247,$2e3,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$d10
	dw $200
	dw $227,$171,$67b,$cf6
	dw $203,$0,$0
	dw $8245,$171,$0,$f10
	dw $200
	dw $227,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$cf6,$f10
	dw $200
	dw $24f,$171,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8241,$171,$1120
	dw $200
	dw $24f,$2e3,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8248,$0,$f20
	dw $201,$0
	dw $227,$2e3,$67b,$b8c
	dw $206,$0,$0
	dw $8209,$0,$f6a,$1140
	dw $200
	dw $22f,$2e3,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8201,$0,$1140
	dw $200
	dw $22f,$2e3,$9b5,$7b5,$8a6
	dw $206,$0,$0
	dw $8209,$0,$0,$f80
	dw $200
	dw $227,$2e3,$7b5,$9b5
	dw $226,$0,$0
	dw $8221,$0,$1180
	dw $220
	dw $227,$19e,$8a6,$9b5
	dw $207,$0,$9b5,$0
	dw $201,$19e
	dw $201,$0
	dw $265,$33d,$67b
	dw $205,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $24f,$19e,$0,$7b5,$8a6
	dw $20d,$0,$0,$9b5
	dw $201,$19e
	dw $201,$0
	dw $267,$33d,$9b5,$67b
	dw $205,$0,$0
	dw $263,$33d,$0
	dw $201,$0
	dw $20f,$19e,$8a6,$9b5,$0
	dw $205,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $22f,$33d,$0,$67b,$9b5
	dw $205,$0,$0
	dw $269,$33d,$0
	dw $201,$0
	dw $24f,$19e,$746,$7b5,$8a6
	dw $205,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $26f,$33d,$7b5,$67b,$0
	dw $205,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $22f,$171,$0,$9b5,$746
	dw $205,$0,$0
	dw $201,$171
	dw $201,$0
	dw $26d,$2e3,$67b,$7b5
	dw $205,$0,$0
	dw $261,$2e3
	dw $201,$0
	dw $24f,$171,$9b5,$7b5,$0
	dw $205,$0,$0
	dw $203,$171,$0
	dw $201,$0
	dw $267,$2e3,$8a6,$67b
	dw $205,$0,$0
	dw $261,$2e3
	dw $201,$0
	dw $20f,$171,$0,$9b5,$9b5
	dw $205,$0,$0
	dw $209,$171,$0
	dw $201,$0
	dw $22f,$2e3,$746,$67b,$8a6
	dw $205,$0,$0
	dw $261,$2e3
	dw $201,$0
	dw $24d,$171,$7b5,$0
	dw $205,$0,$0
	dw $201,$171
	dw $201,$0
	dw $26f,$2e3,$7b5,$67b,$746
	dw $205,$0,$0
	dw $261,$2e3
	dw $201,$0
	dw $225,$229,$9b5
	dw $205,$0,$0
	dw $201,$229
	dw $201,$0
	dw $26d,$453,$67b,$7b5
	dw $205,$0,$0
	dw $261,$453
	dw $201,$0
	dw $245,$229,$7b5
	dw $205,$0,$0
	dw $201,$229
	dw $201,$0
	dw $267,$453,$8a6,$67b
	dw $205,$0,$0
	dw $261,$453
	dw $201,$0
	dw $205,$229,$9b5
	dw $205,$0,$0
	dw $201,$229
	dw $201,$0
	dw $22f,$453,$8a6,$67b,$8a6
	dw $207,$0,$0,$0
	dw $263,$453,$89e
	dw $203,$0,$0
	dw $247,$229,$896,$7b5
	dw $207,$0,$0,$0
	dw $203,$229,$88e
	dw $203,$0,$0
	dw $26f,$453,$886,$67b,$8a6
	dw $20f,$0,$0,$0,$0
	dw $26b,$453,$87e,$89e
	dw $20b,$0,$0,$0
	dw $22d,$229,$9b5,$896
	dw $20d,$0,$0,$0
	dw $209,$229,$88e
	dw $209,$0,$0
	dw $26d,$453,$67b,$886
	dw $20d,$0,$0,$0
	dw $269,$453,$87e
	dw $209,$0,$0
	dw $247,$229,$87e,$7b5
	dw $207,$0,$0,$0
	dw $203,$229,$886
	dw $203,$0,$0
	dw $267,$453,$88e,$67b
	dw $207,$0,$0,$0
	dw $263,$453,$896
	dw $203,$0,$0
	dw $20f,$229,$89e,$9b5,$87e
	dw $20f,$0,$0,$0,$0
	dw $209,$229,$886
	dw $209,$0,$0
	dw $22f,$453,$114d,$67b,$88e
	dw $20f,$0,$0,$0,$0
	dw $26b,$453,$1145,$896
	dw $20b,$0,$0,$0
	dw $24f,$229,$113d,$7b5,$89e
	dw $20f,$0,$0,$0,$0
	dw $203,$229,$1135
	dw $203,$0,$0
	dw $26f,$453,$112d,$67b,$114d
	dw $20f,$0,$0,$0,$0
	dw $26b,$453,$1125,$1145
	dw $20b,$0,$0,$0
	dw $22d,$19e,$9b5,$113d
	dw $20d,$0,$0,$0
	dw $209,$19e,$1135
	dw $209,$0,$0
	dw $26d,$33d,$67b,$112d
	dw $20d,$0,$0,$0
	dw $269,$33d,$1125
	dw $209,$0,$0
	dw $245,$19e,$7b5
	dw $205,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $267,$33d,$8a6,$67b
	dw $205,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $207,$19e,$9b5,$9b5
	dw $205,$0,$0
	dw $203,$19e,$0
	dw $201,$0
	dw $22f,$33d,$b8c,$67b,$8a6
	dw $205,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $24f,$19e,$0,$7b5,$9b5
	dw $205,$0,$0
	dw $209,$19e,$0
	dw $201,$0
	dw $26f,$33d,$f6a,$67b,$b8c
	dw $205,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $22d,$1ed,$9b5,$0
	dw $205,$0,$0
	dw $201,$1ed
	dw $201,$0
	dw $26f,$3da,$0,$67b,$f6a
	dw $205,$0,$0
	dw $261,$3da
	dw $201,$0
	dw $245,$1ed,$7b5
	dw $205,$0,$0
	dw $201,$1ed
	dw $201,$0
	dw $26f,$3da,$e8c,$67b,$0
	dw $205,$0,$0
	dw $261,$3da
	dw $201,$0
	dw $207,$1ed,$b8c,$9b5
	dw $205,$0,$0
	dw $201,$1ed
	dw $201,$0
	dw $22f,$3da,$0,$67b,$e8c
	dw $205,$0,$0
	dw $261,$3da
	dw $201,$0
	dw $24f,$1ed,$8a6,$7b5,$b8c
	dw $205,$0,$0
	dw $201,$1ed
	dw $201,$0
	dw $26f,$3da,$0,$67b,$0
	dw $205,$0,$0
	dw $261,$3da
	dw $201,$0
	dw $22f,$171,$746,$9b5,$8a6
	dw $205,$0,$0
	dw $201,$171
	dw $201,$0
	dw $26d,$2e3,$67b,$0
	dw $205,$0,$0
	dw $261,$2e3
	dw $201,$0
	dw $24f,$171,$746,$7b5,$746
	dw $207,$0,$0,$0
	dw $203,$171,$746
	dw $203,$0,$0
	dw $267,$2e3,$746,$67b
	dw $207,$0,$0,$0
	dw $263,$2e3,$746
	dw $203,$0,$0
	dw $20f,$171,$746,$9b5,$73e
	dw $20d,$0,$0,$0
	dw $209,$171,$736
	dw $209,$0,$0
	dw $22d,$2e3,$67b,$72e
	dw $20d,$0,$0,$0
	dw $269,$2e3,$726
	dw $209,$0,$0
	dw $24f,$171,$7b5,$7b5,$71e
	dw $20f,$0,$0,$0,$0
	dw $203,$171,$7b5
	dw $203,$0,$0
	dw $26f,$2e3,$7b5,$67b,$67b
	dw $20f,$0,$0,$0,$0
	dw $263,$2e3,$7b5
	dw $203,$0,$0
	dw $22f,$171,$7b5,$9b5,$7ad
	dw $20d,$0,$0,$0
	dw $209,$171,$7a5
	dw $209,$0,$0
	dw $26d,$2e3,$67b,$79d
	dw $20d,$0,$0,$0
	dw $269,$2e3,$795
	dw $209,$0,$0
	dw $24f,$171,$8a6,$7b5,$78d
	dw $20f,$0,$0,$0,$0
	dw $203,$171,$8a6
	dw $203,$0,$0
	dw $26f,$2e3,$8a6,$67b,$67b
	dw $20f,$0,$0,$0,$0
	dw $263,$2e3,$8a6
	dw $203,$0,$0
	dw $22f,$5c6,$3a3,$9b5,$89e
	dw $20f,$0,$0,$0,$0
	dw $24b,$5c6,$3a3,$896
	dw $20b,$0,$0,$0
	dw $22f,$2e3,$3a3,$67b,$88e
	dw $20f,$0,$0,$0,$0
	dw $24b,$2e3,$3a3,$886
	dw $20b,$0,$0,$0
	dw $24f,$5c6,$3a3,$7b5,$87e
	dw $20f,$0,$0,$0,$0
	dw $223,$5c6,$3a3
	dw $203,$0,$0
	dw $24f,$2e3,$3a3,$67b,$67b
	dw $20f,$0,$0,$0,$0
	dw $243,$2e3,$3a3
	dw $203,$0,$0
	dw $227,$19e,$67b,$9b5
	dw $205,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $265,$33d,$67b
	dw $205,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $24d,$19e,$7b5,$67b
	dw $205,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $8267,$33d,$746,$67b,$f10
	dw $205,$0,$0
	dw $8261,$33d,$f20
	dw $201,$0
	dw $207,$19e,$7b5,$9b5
	dw $205,$0,$0
	dw $8201,$19e,$f20
	dw $201,$0
	dw $822f,$33d,$0,$67b,$746,$f10
	dw $205,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $24f,$19e,$746,$7b5,$7b5
	dw $205,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $26f,$33d,$7b5,$67b,$67b
	dw $20d,$0,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $22d,$171,$9b5,$746
	dw $205,$0,$0
	dw $201,$171
	dw $201,$0
	dw $26f,$2e3,$0,$67b,$7b5
	dw $205,$0,$0
	dw $261,$2e3
	dw $201,$0
	dw $245,$171,$7b5
	dw $205,$0,$0
	dw $201,$171
	dw $201,$0
	dw $826f,$2e3,$5c6,$67b,$67b,$d10
	dw $20d,$0,$0,$0
	dw $8263,$2e3,$0,$d20
	dw $201,$0
	dw $20f,$171,$746,$9b5,$7b5
	dw $20d,$0,$0,$0
	dw $8203,$171,$0,$d20
	dw $201,$0
	dw $822f,$2e3,$8a6,$67b,$5c6,$d10
	dw $205,$0,$0
	dw $26b,$2e3,$0,$0
	dw $201,$0
	dw $24d,$171,$7b5,$746
	dw $205,$0,$0
	dw $209,$171,$0
	dw $201,$0
	dw $26f,$2e3,$8a6,$67b,$8a6
	dw $207,$0,$9b5,$0
	dw $269,$2e3,$0
	dw $201,$0
	dw $22d,$229,$9b5,$7b5
	dw $20d,$0,$0,$0
	dw $201,$229
	dw $201,$0
	dw $26d,$453,$67b,$8a6
	dw $20d,$0,$0,$9b5
	dw $261,$453
	dw $201,$0
	dw $247,$229,$7b5,$7b5
	dw $205,$0,$0
	dw $201,$229
	dw $201,$0
	dw $826d,$453,$67b,$67b,$b10
	dw $20d,$0,$0,$0
	dw $8261,$453,$b20
	dw $201,$0
	dw $20f,$229,$7b5,$9b5,$7b5
	dw $207,$0,$0,$0
	dw $8203,$229,$7b5,$b20
	dw $203,$0,$0
	dw $8227,$453,$7b5,$67b,$b10
	dw $207,$0,$0,$0
	dw $263,$453,$7b5
	dw $203,$0,$0
	dw $24f,$229,$7b5,$7b5,$7ad
	dw $20f,$0,$0,$0,$0
	dw $209,$229,$7a5
	dw $209,$0,$0
	dw $26d,$453,$67b,$79d
	dw $20d,$0,$0,$0
	dw $269,$453,$795
	dw $209,$0,$0
	dw $22f,$229,$67b,$9b5,$78d
	dw $20f,$0,$0,$0,$0
	dw $203,$229,$67b
	dw $203,$0,$0
	dw $26f,$453,$67b,$67b,$67b
	dw $20f,$0,$0,$0,$0
	dw $263,$453,$cf6
	dw $203,$0,$0
	dw $24f,$229,$cf6,$7b5,$673
	dw $20f,$0,$0,$0,$0
	dw $209,$229,$66b
	dw $209,$0,$0
	dw $826f,$453,$746,$67b,$663,$910
	dw $20f,$0,$0,$0,$0
	dw $826b,$453,$746,$cd6,$920
	dw $20b,$0,$0,$0
	dw $20f,$229,$746,$9b5,$cce
	dw $20f,$0,$0,$0,$0
	dw $8203,$229,$e8c,$920
	dw $203,$0,$0
	dw $822f,$453,$e8c,$67b,$73e,$910
	dw $20f,$0,$0,$0,$0
	dw $269,$453,$736
	dw $209,$0,$0
	dw $24f,$229,$8a6,$7b5,$72e
	dw $20f,$0,$0,$0,$0
	dw $20b,$229,$8a6,$e6c
	dw $20b,$0,$0,$0
	dw $26f,$453,$8a6,$67b,$e64
	dw $20f,$0,$0,$0,$0
	dw $263,$453,$114d
	dw $203,$0,$0
	dw $22f,$19e,$114d,$9b5,$89e
	dw $20f,$0,$0,$0,$0
	dw $209,$19e,$896
	dw $209,$0,$0
	dw $26d,$33d,$67b,$88e
	dw $20d,$0,$0,$0
	dw $269,$33d,$112d
	dw $209,$0,$0
	dw $24d,$19e,$7b5,$1125
	dw $20d,$0,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $826f,$33d,$8a6,$67b,$67b,$710
	dw $20d,$0,$0,$0
	dw $8261,$33d,$720
	dw $201,$0
	dw $20f,$19e,$7b5,$9b5,$7b5
	dw $20d,$0,$0,$0
	dw $8201,$19e,$720
	dw $201,$0
	dw $822f,$33d,$0,$67b,$8a6,$710
	dw $205,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $24f,$19e,$4da,$7b5,$7b5
	dw $205,$0,$0
	dw $201,$19e
	dw $201,$0
	dw $26f,$33d,$746,$67b,$67b
	dw $20d,$0,$0,$0
	dw $261,$33d
	dw $201,$0
	dw $22d,$1ed,$9b5,$4da
	dw $205,$0,$0
	dw $201,$1ed
	dw $201,$0
	dw $26d,$3da,$67b,$746
	dw $205,$0,$0
	dw $261,$3da
	dw $201,$0
	dw $247,$1ed,$0,$7b5
	dw $205,$0,$0
	dw $201,$1ed
	dw $201,$0
	dw $8267,$3da,$3da,$67b,$510
	dw $205,$0,$0
	dw $8261,$3da,$520
	dw $201,$0
	dw $20f,$1ed,$453,$9b5,$7b5
	dw $20d,$0,$0,$0
	dw $8201,$1ed,$520
	dw $201,$0
	dw $822f,$3da,$0,$67b,$3da,$510
	dw $205,$0,$0
	dw $261,$3da
	dw $201,$0
	dw $24f,$1ed,$5c6,$7b5,$453
	dw $205,$0,$0
	dw $201,$1ed
	dw $201,$0
	dw $26d,$3da,$67b,$67b
	dw $20d,$0,$0,$0
	dw $261,$3da
	dw $201,$0
	dw $22f,$229,$453,$9b5,$5c6
	dw $205,$0,$0
	dw $201,$229
	dw $201,$0
	dw $265,$453,$67b
	dw $205,$0,$0
	dw $261,$453
	dw $201,$0
	dw $24f,$229,$453,$7b5,$44b
	dw $207,$0,$0,$0
	dw $203,$229,$453
	dw $203,$0,$0
	dw $8267,$453,$453,$67b,$310
	dw $207,$0,$0,$0
	dw $8263,$453,$453,$320
	dw $203,$0,$0
	dw $20f,$229,$8a6,$9b5,$44b
	dw $20d,$0,$0,$0
	dw $8209,$229,$443,$320
	dw $209,$0,$0
	dw $822d,$453,$67b,$43b,$310
	dw $20d,$0,$0,$0
	dw $269,$453,$433
	dw $209,$0,$0
	dw $24f,$229,$8a6,$7b5,$87e
	dw $20f,$0,$0,$0,$0
	dw $203,$229,$8a6
	dw $203,$0,$0
	dw $26f,$453,$8a6,$67b,$67b
	dw $20f,$0,$0,$0,$0
	dw $263,$453,$8a6
	dw $203,$0,$0
	dw $22f,$453,$67b,$9b5,$89e
	dw $20d,$0,$0,$0
	dw $209,$453,$896
	dw $209,$0,$0
	dw $26d,$453,$67b,$88e
	dw $20d,$0,$0,$0
	dw $269,$453,$886
	dw $209,$0,$0
	dw $20f,$453,$67b,$7b5,$66b
	dw $207,$0,$0,$0
	dw $203,$453,$67b
	dw $203,$0,$0
	dw $267,$453,$67b,$67b
	dw $207,$0,$0,$0
	dw $263,$453,$67b
	dw $203,$0,$0
	dw $20f,$114,$67b,$9b5,$221
	dw $206,$0,$0
	dw $200
	dw $200
	dw $224,$67b
	dw $204,$0
	dw $220
	dw $200
	dw $224,$7b5
	dw $204,$0
	dw $220
	dw $200
	dw $224,$67b
	dw $204,$0
	dw $220
	dw $200
	dw $26f,$19e,$67b,$7b5,$0
	dw $203,$0,$0
	dw $205,$19e,$0
	dw $200
	dw $207,$33d,$7b5,$67b
	dw $206,$0,$0
	dw $208,$7b5
	dw $200
	dw $20f,$19e,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $201,$19e
	dw $200
	dw $20f,$33d,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $208,$0
	dw $200
	dw $207,$19e,$67b,$b8c
	dw $207,$0,$0,$0
	dw $209,$19e,$f6a
	dw $200
	dw $20f,$33d,$7b5,$67b,$0
	dw $206,$0,$0
	dw $200
	dw $200
	dw $20f,$19e,$9b5,$7b5,$e8c
	dw $207,$0,$0,$0
	dw $209,$19e,$0
	dw $200
	dw $207,$33d,$7b5,$9b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$171,$67b,$b8c
	dw $203,$0,$0
	dw $205,$171,$0
	dw $200
	dw $207,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $208,$b8c
	dw $200
	dw $20f,$171,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $201,$171
	dw $200
	dw $20f,$2e3,$b8c,$cf6,$114d
	dw $206,$0,$0
	dw $208,$0
	dw $200
	dw $207,$171,$67b,$b8c
	dw $207,$0,$0,$0
	dw $209,$171,$114d
	dw $200
	dw $20f,$2e3,$7b5,$67b,$0
	dw $206,$0,$0
	dw $200
	dw $200
	dw $20f,$171,$9b5,$7b5,$8a6
	dw $207,$0,$0,$0
	dw $209,$171,$0
	dw $200
	dw $207,$2e3,$7b5,$9b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$114,$67b,$746
	dw $203,$0,$0
	dw $205,$114,$0
	dw $200
	dw $207,$229,$7b5,$67b
	dw $206,$0,$0
	dw $208,$746
	dw $200
	dw $20f,$114,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $201,$114
	dw $200
	dw $20f,$229,$b8c,$cf6,$e8c
	dw $206,$0,$0
	dw $208,$0
	dw $200
	dw $207,$114,$67b,$b8c
	dw $207,$0,$0,$0
	dw $209,$114,$e8c
	dw $200
	dw $20f,$229,$7b5,$67b,$0
	dw $206,$0,$0
	dw $200
	dw $200
	dw $20f,$114,$9b5,$7b5,$b8c
	dw $207,$0,$0,$0
	dw $209,$114,$0
	dw $200
	dw $207,$229,$7b5,$9b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$114,$67b,$cf6
	dw $203,$0,$0
	dw $205,$114,$0
	dw $200
	dw $207,$229,$7b5,$67b
	dw $206,$0,$0
	dw $208,$cf6
	dw $200
	dw $20f,$114,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $201,$114
	dw $200
	dw $20f,$229,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $208,$0
	dw $200
	dw $207,$114,$67b,$b8c
	dw $207,$0,$0,$0
	dw $209,$114,$f6a
	dw $200
	dw $20f,$229,$7b5,$67b,$0
	dw $206,$0,$0
	dw $200
	dw $200
	dw $20f,$114,$9b5,$7b5,$8a6
	dw $207,$0,$0,$0
	dw $209,$114,$0
	dw $200
	dw $207,$229,$7b5,$9b5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$19e,$67b,$7b5
	dw $203,$0,$0
	dw $8205,$19e,$0,$310
	dw $200
	dw $207,$33d,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$7b5,$310
	dw $200
	dw $20f,$19e,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$19e,$510
	dw $200
	dw $20f,$33d,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8208,$0,$310
	dw $200
	dw $207,$19e,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8209,$19e,$f6a,$510
	dw $200
	dw $20f,$33d,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $20f,$19e,$9b5,$7b5,$e8c
	dw $207,$0,$0,$0
	dw $8209,$19e,$0,$710
	dw $200
	dw $207,$33d,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $207,$1ed,$67b,$b8c
	dw $203,$0,$0
	dw $8205,$1ed,$0,$710
	dw $200
	dw $207,$3da,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$b8c,$710
	dw $200
	dw $20f,$1ed,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$1ed,$910
	dw $200
	dw $20f,$3da,$b8c,$cf6,$114d
	dw $206,$0,$0
	dw $8208,$0,$710
	dw $200
	dw $207,$1ed,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8209,$1ed,$114d,$910
	dw $200
	dw $20f,$3da,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $20f,$1ed,$9b5,$7b5,$8a6
	dw $207,$0,$0,$0
	dw $8209,$1ed,$0,$b10
	dw $200
	dw $207,$3da,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $207,$171,$67b,$746
	dw $203,$0,$0
	dw $8205,$171,$0,$b10
	dw $200
	dw $207,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$746,$b10
	dw $200
	dw $20f,$171,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$171,$d10
	dw $200
	dw $20f,$2e3,$b8c,$cf6,$e8c
	dw $206,$0,$0
	dw $8208,$0,$b10
	dw $200
	dw $207,$171,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8209,$171,$e8c,$d10
	dw $200
	dw $20f,$2e3,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $20f,$171,$9b5,$7b5,$b8c
	dw $207,$0,$0,$0
	dw $8209,$171,$0,$f10
	dw $200
	dw $207,$2e3,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $227,$171,$67b,$cf6
	dw $203,$0,$0
	dw $8205,$171,$0,$f10
	dw $200
	dw $227,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$cf6,$f10
	dw $200
	dw $22f,$171,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$171,$1120
	dw $200
	dw $22f,$2e3,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8208,$0,$f20
	dw $201,$0
	dw $247,$2e3,$67b,$b8c
	dw $206,$0,$0
	dw $8249,$0,$f6a,$1140
	dw $200
	dw $24f,$2e3,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8241,$0,$1140
	dw $200
	dw $24f,$2e3,$9b5,$7b5,$8a6
	dw $246,$0,$0
	dw $8249,$0,$0,$f80
	dw $240
	dw $247,$2e3,$7b5,$9b5
	dw $246,$0,$0
	dw $8241,$0,$1180
	dw $240
	dw $227,$19e,$67b,$7b5
	dw $203,$0,$0
	dw $8205,$19e,$0,$1110
	dw $200
	dw $267,$33d,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$7b5,$1110
	dw $200
	dw $24f,$19e,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$19e,$f10
	dw $200
	dw $26f,$33d,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8268,$0,$1110
	dw $200
	dw $207,$19e,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8269,$19e,$f6a,$f10
	dw $200
	dw $22f,$33d,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $24f,$19e,$9b5,$7b5,$e8c
	dw $207,$0,$0,$0
	dw $8209,$19e,$0,$d10
	dw $200
	dw $267,$33d,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $227,$171,$67b,$b8c
	dw $203,$0,$0
	dw $8205,$171,$0,$d10
	dw $200
	dw $227,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$b8c,$d10
	dw $200
	dw $24f,$171,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$171,$b10
	dw $200
	dw $26f,$2e3,$b8c,$cf6,$114d
	dw $206,$0,$0
	dw $8268,$0,$d10
	dw $200
	dw $207,$171,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8249,$171,$114d,$b10
	dw $200
	dw $22f,$2e3,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$b10
	dw $200
	dw $24f,$171,$9b5,$7b5,$8a6
	dw $207,$0,$0,$0
	dw $8209,$171,$0,$910
	dw $200
	dw $247,$2e3,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$b10
	dw $200
	dw $227,$114,$67b,$746
	dw $203,$0,$0
	dw $8205,$114,$0,$910
	dw $200
	dw $267,$229,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$746,$910
	dw $200
	dw $24f,$114,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$114,$710
	dw $200
	dw $26f,$229,$b8c,$cf6,$e8c
	dw $206,$0,$0
	dw $8268,$0,$910
	dw $200
	dw $207,$114,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8269,$114,$e8c,$710
	dw $200
	dw $22f,$229,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $24f,$114,$9b5,$7b5,$b8c
	dw $207,$0,$0,$0
	dw $8209,$114,$0,$510
	dw $200
	dw $267,$229,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $227,$114,$67b,$cf6
	dw $203,$0,$0
	dw $8205,$114,$0,$510
	dw $200
	dw $227,$229,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$cf6,$510
	dw $200
	dw $24f,$114,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$114,$310
	dw $200
	dw $26f,$229,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8248,$0,$510
	dw $200
	dw $227,$114,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8249,$114,$f6a,$310
	dw $200
	dw $22f,$229,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$310
	dw $200
	dw $24f,$114,$9b5,$7b5,$8a6
	dw $207,$0,$0,$0
	dw $8229,$114,$0,$510
	dw $200
	dw $247,$229,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$310
	dw $200
	dw $227,$19e,$67b,$7b5
	dw $203,$0,$0
	dw $8205,$19e,$0,$310
	dw $200
	dw $267,$33d,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$7b5,$310
	dw $200
	dw $24f,$19e,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$19e,$510
	dw $200
	dw $26f,$33d,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8268,$0,$310
	dw $200
	dw $207,$19e,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8269,$19e,$f6a,$510
	dw $200
	dw $22f,$33d,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $24f,$19e,$9b5,$7b5,$e8c
	dw $207,$0,$0,$0
	dw $8209,$19e,$0,$710
	dw $200
	dw $267,$33d,$7b5,$9b5
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $227,$1ed,$67b,$b8c
	dw $203,$0,$0
	dw $8205,$1ed,$0,$710
	dw $200
	dw $227,$3da,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$b8c,$710
	dw $200
	dw $24f,$1ed,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$1ed,$910
	dw $200
	dw $26f,$3da,$b8c,$cf6,$114d
	dw $206,$0,$0
	dw $8268,$0,$710
	dw $200
	dw $207,$1ed,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8249,$1ed,$114d,$910
	dw $200
	dw $22f,$3da,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $24f,$1ed,$9b5,$7b5,$8a6
	dw $207,$0,$0,$0
	dw $8209,$1ed,$0,$b10
	dw $200
	dw $247,$3da,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$910
	dw $200
	dw $227,$171,$67b,$746
	dw $203,$0,$0
	dw $8205,$171,$0,$b10
	dw $200
	dw $267,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$746,$b10
	dw $200
	dw $24f,$171,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8201,$171,$d10
	dw $200
	dw $26f,$2e3,$b8c,$cf6,$e8c
	dw $206,$0,$0
	dw $8268,$0,$b10
	dw $200
	dw $207,$171,$67b,$b8c
	dw $207,$0,$0,$0
	dw $8269,$171,$e8c,$d10
	dw $200
	dw $22f,$2e3,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $24f,$171,$9b5,$7b5,$b8c
	dw $207,$0,$0,$0
	dw $8209,$171,$0,$f10
	dw $200
	dw $247,$2e3,$7b5,$9b5
	dw $206,$0,$0
	dw $8240,$d10
	dw $200
	dw $227,$171,$67b,$cf6
	dw $203,$0,$0
	dw $8245,$171,$0,$f10
	dw $200
	dw $227,$2e3,$7b5,$67b
	dw $206,$0,$0
	dw $8208,$cf6,$f10
	dw $200
	dw $24f,$171,$cf6,$7b5,$0
	dw $207,$0,$0,$0
	dw $8241,$171,$1120
	dw $200
	dw $24f,$2e3,$b8c,$cf6,$f6a
	dw $206,$0,$0
	dw $8248,$0,$f20
	dw $201,$0
	dw $227,$2e3,$67b,$b8c
	dw $206,$0,$0
	dw $8209,$0,$f6a,$1140
	dw $200
	dw $22f,$2e3,$7b5,$67b,$0
	dw $206,$0,$0
	dw $8201,$0,$1140
	dw $200
	dw $22f,$2e3,$9b5,$7b5,$8a6
	dw $206,$0,$0
	dw $8209,$0,$0,$f80
	dw $200
	dw $227,$2e3,$7b5,$9b5
	dw $226,$0,$0
	dw $8221,$0,$1180
	dw $220
	dw $24f,$33d,$335,$19e,$196
	dw $201,$0
	dw $201,$33d
	dw $201,$0
	dw $201,$33d
	dw $200
	dw $200
	dw $200
	dw $20b,$0,$33d,$19e
	dw $20a,$0,$0
	dw $20a,$33d,$19e
	dw $20a,$0,$0
	dw $20a,$33d,$19e
	dw $200
	dw $200
	dw $200
	dw $20a,$0,$19e
	dw $208,$0
	dw $208,$19e
	dw $208,$0
	dw $208,$19e
	dw $200
	dw $200
	dw $200
	dw $20c,$0,$19e
	dw $208,$0
	dw $208,$19e
	dw $208,$0
	dw $208,$19e
	dw $200
	dw $200
	dw $200
	dw $20c,$19e,$0
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $204,$0
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
.loop:
	dw $7f1f,0,0,0,0,NOP_2
	dw 0


END _asm

AUTORUN:

	REM 'ϱӱױ'
	CLS
	PRINT AT 3,0;"ϱ"
	PRINT AT 6,0;" SQUAT",," SHIRU, 06/17"
	PRINT AT 11,3;"MUSIC: CATCHING UP";TAB 3;"AUTHOR: SHIRU, 07/18"
	PRINT AT 16,1;"TYPE ANY KEY TO HEAR THE MUSIC"
	PRINT AT 19,0;""
.waitk:
	IF INKEY$="" THEN GOTO #.waitk#
	RAND USR #start
	GOTO #.waitk#


	include 'SINCL-ZX\ZX81DISP.INC' 	 ; include D_FILE and needed memory areas

VARS_ADDR:
	db 80h

WORKSPACE:

assert ($-MEMST)<MEMAVL
// end of program
