format zx81
;labelusenumeric
;LISTOFF

	// hardware options to be set and change defaults in ZX81DEF.INC
	MEMAVL	   =	   MEM_16K	   // can be MEM_1K, MEM_2K, MEM_4K, MEM_8K, MEM_16K, MEM_32K, MEM_48K
					   // default value is MEM_16K
	STARTMODE  EQU	   SLOW_MODE	   // SLOW or FAST
	DFILETYPE  EQU	   COLLAPSED	   // COLLAPSED or EXPANDED or AUTO
	STARTUPMSG EQU	  'CREATED WITH ZX81-IDE' // any message will be shown on screen after loading, max. 32 chars

	include 'SINCL-ZX\ZX81.INC'	   // definitions of constants

;LISTON



	REM _hide _noedit  _asm

start:
	;test code

	ld hl,music_data1
	call play
	call	$0f2b		;SLOW
	ret
	
	
	
	;engine code

;squat by Shiru, 06'17
;Squeeker like, just without the output value table
;4 channels of tone with different duty cycle
;sample drums, non-interrupting
;customizeable noise percussion, interrupting


;music data is all 16-bit words, first control then a few optional ones

;control word is PSSSSSSS DDDN4321, where P=percussion,S=speed, D=drum, N=noise mode, 4321=channels
;D triggers non-interruping sample drum
;P trigger
;if 1, channel 1 freq follows
;if 2, channel 2 freq follows
;if 3, channel 3 freq follows
;if 4, channel 4 freq follows
;if N, channel 4 mode follows, it is either $0000 (normal) or $04cb (noise)
;if P, percussion follows, LSB=volume, MSB=pitch



RLC_H=$04cb		;to enable noise mode
NOP_2=$0000		;to disable noise mode
RLC_HL=$06cb		;to enable sample reading
ADD_IX_IX=$29dd 	;to disable sample reading


play:

;        di
	call	$0f23		;FAST

	ld e,(hl)
	inc hl
	ld d,(hl)
	inc hl
	ld (pattern_ptr),de
	
	ld e,(hl)
	inc hl
	ld d,(hl)
	
	ld (loop_ptr),de

	dec hl
	ld (sample_list),hl
	
	ld hl,ADD_IX_IX
	ld (sample_read),hl
	ld hl,NOP_2				;normal mode
	ld (noise_mode),hl
	
	ld ix,0 				;needs to be 0 to skip sample reading

	ld c,0
	exx
	ld de,$0808				;sample bit counter and reload value

play_loop:

pattern_ptr=$+1
	ld sp,0
	
return_loop:

	pop bc					;control word
						;B=duration of the row (0=loop)
						;C=flags DDDN4321 (Drum, Noise, 1-4 channel update)
	ld a,b
	or a
	jp nz,no_loop
	
loop_ptr=$+1
	ld sp,0
	
	jp return_loop
	
no_loop:

	ld a,c
	
	rra
	jr nc,skip_note_0
	
	pop hl
	ld (ch0_add),hl
	
skip_note_0:

	rra
	jr nc,skip_note_1

	pop hl
	ld (ch1_add),hl
	
skip_note_1:

	rra
	jr nc,skip_note_2
	
	pop hl
	ld (ch2_add),hl
	
skip_note_2:

	rra
	jr nc,skip_note_3
	
	pop hl
	ld (ch3_add),hl
	
skip_note_3:

	rra
	jr nc,skip_mode_change
	
	pop hl					;nop:nop or rlc h
	ld (noise_mode),hl

skip_mode_change:

	and 7
	jp z,skip_drum
	
sample_list=$+1
	ld hl,0 				;sample_list-2
	add a,a
	add a,l
	ld l,a
	ld a,(hl)
	inc l
	ld h,(hl)
	ld l,a
	ld (sample_ptr),hl
	ld hl,RLC_HL
	ld (sample_read),hl

skip_drum:

	bit 7,b 				;check percussion flag
	jp z,skip_percussion

	res 7,b 				;clear percussion flag
	dec b					;compensate speed

	ld (noise_bc),bc
	ld (noise_de),de

	pop hl					;read percussion parameters

	ld a,l					;noise volume
	ld (noise_volume),a
	ld b,h					;noise pitch
	ld c,h
	ld de,$2174				;utz's rand seed			
	exx
	ld bc,811				;noise duration, takes as long as inner sound loop

noise_loop:

	exx				;4
	dec c				;4
	jr nz,noise_skip		;7/12
	ld c,b				;4
	add hl,de			;11
	rlc h				;8	utz's noise generator idea
	inc d				;4	improves randomness
	jp noise_next			;10
	
noise_skip:

	jr $+2				;12
	jr $+2				;12
	nop				;4
	nop				;4
	
noise_next:

	ld a,h				;4
	
noise_volume=$+1
	cp $80				;7
;        sbc a,a                         ;4
;        out ($fe),a                     ;11

	jp c,HP1	;[10]

	in a,($fe)	;[11]
	jp LP1		;[10]

HP1:	out ($ff),a	;[11]
	jp LP1		;[10]
LP1:
	exx				;4

	dec bc				;6
	ld a,b				;4
	or c				;4
	jp nz,noise_loop		;10=106t

	exx

noise_bc=$+1
	ld bc,0
noise_de=$+1
	ld de,0



skip_percussion:

	ld (pattern_ptr),sp

sample_ptr=$+1
	ld hl,0

	ld c,0					;internal loop runs 256 times

sound_loop:

sample_read=$
	rlc (hl)			;15	rotate sample bits in place, rl (hl) or add ix,ix (dummy operation)
	sbc a,a 			;4	sbc a,a to make bit into 0 or 255, or xor a to keep it 0

	dec e				;4--+	count bits
	jp z,sample_cycle		;10 |
	jp sample_next			;10

sample_cycle:

	ld e,d				;4  |	reload counter
	inc hl				;6--+	advance pointer --24t

sample_next:

	exx				;4	squeeker type unrolled code
	ld b,a				;4	sample mask
	xor a				;4
	
	ld sp,sound_list		;10
		
	pop de				;10	ch0_acc
	pop hl				;10	ch0_add
	add hl,de			;11
	rla				;4
	ld (ch0_acc),hl 		;16
						
	pop de				;10	ch1_acc
	pop hl				;10	ch1_add
	add hl,de			;11
	rla				;4
	ld (ch1_acc),hl 		;16
	
	pop de				;10	ch2_acc
	pop hl				;10	ch2_add
	add hl,de			;11
	rla							;4
	ld (ch2_acc),hl 		;16

	pop de				;10	ch3_acc
	pop hl				;10	ch3_add
	add hl,de			;11
	
noise_mode=$
;        ds 2,0                          ;8      rlc h for noise effects
	rb 2

	rla				;4
	ld (ch3_acc),hl 		;16

	add a,c 			;4	no table like in Squeeker, channels summed as is, for uneven 'volume'
	add a,$ff			;7
	sbc a,$ff			;7
	ld c,a				;4
	sbc a,a 			;4

	or b				;4	mix sample
	
;        out ($fe),a                     ;11

	and $10 	;[7]
	jp nz,HP2	;[10]

	in a,($fe)	;[11]
	jp LP2		;[10]

HP2:	out ($ff),a	;[11]
	jp LP2		;[10]
LP2:

	exx				;4

	dec c				;4
	jp nz,sound_loop		;10=374  ;336t


	dec hl					;last byte of a 256/8 byte sample packet is $80 means it was the last packet
	ld a,(hl)
	inc hl
	cp $80
	jr nz,sample_no_stop

	ld hl,ADD_IX_IX
	ld (sample_read),hl			;disable sample reading

sample_no_stop:

	djnz sound_loop

	ld (sample_ptr),hl
	
	jp play_loop
	
	
		
;variables in the sound_list can't be reordered because of stack-based fetching

sound_list:

ch0_add 	dw 0
ch0_acc 	dw 0
ch1_add 	dw 0
ch1_acc 	dw 0
ch2_add 	dw 0
ch2_acc 	dw 0
ch3_add 	dw 0
ch3_acc 	dw 0


;compiled music data

	align 2

music_data1:
	dw .pattern
	dw .loop
;sample data

.sample_list:
	dw .sample_1
	dw .sample_2
	dw .sample_3
	dw .sample_4
	dw .sample_5
	dw .sample_6
	dw .sample_7
	align 256/8

.sample_1:
.sample_2:
.sample_3:
.sample_4:
.sample_5:
.sample_6:
.sample_7:


.pattern:
	dw $8419,$19e,$9b5,NOP_2,$1180
	dw $400
	dw $8409,$0,$0,$110
	dw $8400,$110
	dw $8409,$19e,$9b5,$780
	dw $400
	dw $8409,$33d,$0,$1180
	dw $8400,$110
	dw $8409,$171,$9b5,$110
	dw $400
	dw $8409,$2e3,$0,$1180
	dw $8400,$110
	dw $8409,$19e,$9b5,$780
	dw $400
	dw $8409,$33d,$0,$1180
	dw $8400,$110
	dw $8405,$19e,$9b5,$1180
	dw $400
	dw $8405,$0,$0,$110
	dw $8400,$110
	dw $8405,$19e,$9b5,$780
	dw $400
	dw $8405,$33d,$0,$1180
	dw $8400,$110
	dw $8405,$149,$a49,$110
	dw $400
	dw $8405,$292,$0,$1180
	dw $8400,$110
	dw $8405,$171,$b8c,$780
	dw $400
	dw $8405,$2e3,$0,$780
	dw $8400,$780
	dw $8403,$149,$67b,$1180
	dw $400
	dw $8403,$0,$0,$110
	dw $8400,$110
	dw $8403,$149,$67b,$780
	dw $400
	dw $8403,$292,$0,$1180
	dw $8400,$110
	dw $8403,$136,$67b,$110
	dw $400
	dw $8403,$26d,$0,$1180
	dw $8400,$110
	dw $8403,$149,$67b,$780
	dw $400
	dw $8403,$292,$0,$1180
	dw $8400,$110
	dw $8405,$149,$67b,$1180
	dw $400
	dw $8405,$0,$0,$110
	dw $8400,$110
	dw $8405,$149,$67b,$780
	dw $400
	dw $8405,$292,$0,$1180
	dw $8400,$110
	dw $8405,$149,$a49,$110
	dw $400
	dw $8405,$292,$0,$1180
	dw $8400,$110
	dw $8405,$171,$b8c,$780
	dw $400
	dw $8405,$2e3,$0,$780
	dw $8400,$780
	dw $8409,$19e,$9b5,$1180
	dw $400
	dw $8409,$0,$0,$110
	dw $8400,$110
	dw $8409,$19e,$9b5,$780
	dw $400
	dw $8409,$33d,$0,$1180
	dw $8400,$110
	dw $8409,$171,$9b5,$110
	dw $400
	dw $8409,$2e3,$0,$1180
	dw $8400,$110
	dw $8409,$19e,$9b5,$780
	dw $400
	dw $8409,$33d,$0,$1180
	dw $8400,$110
	dw $8405,$19e,$9b5,$1180
	dw $400
	dw $8405,$0,$0,$110
	dw $8400,$110
	dw $8405,$19e,$9b5,$780
	dw $400
	dw $8405,$33d,$0,$1180
	dw $8400,$110
	dw $8405,$149,$a49,$110
	dw $400
	dw $8405,$292,$0,$1180
	dw $8400,$110
	dw $8405,$171,$b8c,$780
	dw $400
	dw $8405,$2e3,$0,$780
	dw $8400,$780
	dw $8403,$114,$9b5,$1180
	dw $400
	dw $8403,$0,$0,$110
	dw $8400,$110
	dw $8403,$114,$9b5,$780
	dw $400
	dw $8403,$229,$0,$1180
	dw $8400,$110
	dw $8403,$f6,$9b5,$110
	dw $400
	dw $8403,$1ed,$0,$1180
	dw $8400,$110
	dw $8403,$114,$9b5,$780
	dw $400
	dw $8403,$229,$0,$1180
	dw $8400,$110
	dw $8405,$136,$9b5,$1180
	dw $400
	dw $8405,$0,$0,$110
	dw $8400,$110
	dw $8405,$136,$9b5,$780
	dw $400
	dw $8405,$26d,$0,$1180
	dw $8400,$110
	dw $8403,$149,$a49,$110
	dw $400
	dw $8403,$292,$0,$1180
	dw $8400,$110
	dw $8403,$171,$b8c,$780
	dw $400
	dw $403,$2e3,$0
	dw $400
	dw $8407,$19e,$9ad,$9b5,$1180
	dw $401,$33d
	dw $407,$0,$0,$8a6
	dw $401,$19e
	dw $840b,$33d,$9b5,$9b5,$110
	dw $401,$0
	dw $840f,$19e,$0,$9b5,$8a6,$110
	dw $401,$33d
	dw $8407,$0,$9b5,$8a6,$780
	dw $400
	dw $40a,$0,$9b5
	dw $400
	dw $840f,$19e,$9ad,$9b5,$8a6,$110
	dw $400
	dw $8407,$33d,$0,$8a6,$110
	dw $400
	dw $40b,$19e,$9ad,$9b5
	dw $401,$33d
	dw $40b,$0,$0,$8a6
	dw $401,$19e
	dw $8407,$33d,$9b5,$0,$1180
	dw $401,$0
	dw $403,$19e,$0
	dw $401,$33d
	dw $840b,$0,$a49,$0,$780
	dw $400
	dw $403,$19e,$0
	dw $400
	dw $8403,$0,$b8c,$110
	dw $400
	dw $8403,$33d,$0,$110
	dw $400
	dw $8407,$171,$67b,$9b5,$1180
	dw $401,$2e3
	dw $407,$0,$0,$8a6
	dw $401,$171
	dw $840b,$2e3,$67b,$9b5,$110
	dw $401,$0
	dw $840f,$171,$0,$9b5,$8a6,$110
	dw $401,$2e3
	dw $8407,$0,$67b,$8a6,$780
	dw $400
	dw $40a,$0,$9b5
	dw $400
	dw $840f,$171,$67b,$9b5,$8a6,$110
	dw $400
	dw $8407,$2e3,$0,$8a6,$110
	dw $400
	dw $40b,$171,$67b,$9b5
	dw $401,$2e3
	dw $40b,$0,$0,$8a6
	dw $401,$171
	dw $8407,$2e3,$67b,$0,$1180
	dw $401,$0
	dw $403,$171,$0
	dw $401,$2e3
	dw $840b,$0,$a49,$0,$780
	dw $400
	dw $403,$171,$0
	dw $400
	dw $8407,$0,$b8c,$67b,$110
	dw $400
	dw $8407,$2e3,$0,$746,$110
	dw $400
	dw $840f,$114,$9b5,$7b5,$67b,$1180
	dw $401,$229
	dw $40b,$0,$0,$746
	dw $401,$114
	dw $840b,$229,$9b5,$7b5,$110
	dw $401,$0
	dw $8407,$114,$0,$746,$110
	dw $401,$229
	dw $8403,$0,$9b5,$780
	dw $400
	dw $40a,$0,$746
	dw $400
	dw $8407,$114,$9b5,$67b,$110
	dw $400
	dw $8403,$229,$0,$110
	dw $400
	dw $40b,$114,$9b5,$67b
	dw $401,$229
	dw $403,$0,$0
	dw $401,$114
	dw $8407,$229,$9b5,$0,$1180
	dw $401,$0
	dw $403,$114,$0
	dw $401,$229
	dw $840b,$0,$a49,$0,$780
	dw $400
	dw $403,$114,$0
	dw $400
	dw $8407,$0,$b8c,$67b,$110
	dw $400
	dw $8407,$229,$0,$746,$110
	dw $400
	dw $840f,$136,$9b5,$7b5,$67b,$1180
	dw $401,$26d
	dw $40b,$0,$0,$746
	dw $401,$136
	dw $840b,$26d,$9b5,$7b5,$110
	dw $401,$0
	dw $8407,$136,$0,$8a6,$110
	dw $401,$26d
	dw $8403,$0,$9b5,$780
	dw $400
	dw $40a,$0,$8a6
	dw $400
	dw $8407,$136,$9b5,$7b5,$110
	dw $400
	dw $8403,$26d,$0,$110
	dw $400
	dw $40b,$136,$9b5,$7b5
	dw $401,$26d
	dw $403,$0,$0
	dw $401,$136
	dw $8407,$26d,$9b5,$746,$1180
	dw $401,$0
	dw $403,$136,$0
	dw $401,$26d
	dw $840b,$0,$a49,$746,$780
	dw $400
	dw $403,$136,$0
	dw $400
	dw $8407,$0,$b8c,$0,$110
	dw $400
	dw $8403,$26d,$0,$110
	dw $400
	dw $840f,$19e,$9ad,$9b5,$0,$1180
	dw $401,$33d
	dw $8407,$0,$0,$8a6,$110
	dw $8401,$19e,$110
	dw $840b,$33d,$9ad,$9b5,$780
	dw $401,$0
	dw $840f,$19e,$0,$9b5,$8a6,$1180
	dw $8401,$33d,$110
	dw $8407,$0,$9b5,$8a6,$110
	dw $400
	dw $840a,$0,$9b5,$1180
	dw $8400,$110
	dw $840f,$19e,$9ad,$9b5,$8a6,$780
	dw $400
	dw $8407,$33d,$0,$8a6,$1180
	dw $8400,$110
	dw $840b,$19e,$9ad,$9b5,$1180
	dw $401,$33d
	dw $840b,$0,$0,$8a6,$110
	dw $8401,$19e,$110
	dw $8407,$33d,$9b5,$0,$780
	dw $401,$0
	dw $8403,$19e,$0,$1180
	dw $8401,$33d,$110
	dw $840b,$0,$a49,$0,$110
	dw $400
	dw $8403,$19e,$0,$1180
	dw $8400,$110
	dw $8403,$0,$b8c,$780
	dw $400
	dw $8403,$33d,$0,$780
	dw $8400,$780
	dw $8407,$171,$67b,$9b5,$1180
	dw $401,$2e3
	dw $8407,$0,$0,$8a6,$110
	dw $8401,$171,$110
	dw $840b,$2e3,$67b,$9b5,$780
	dw $401,$0
	dw $840f,$171,$0,$9b5,$8a6,$1180
	dw $8401,$2e3,$110
	dw $8407,$0,$67b,$8a6,$110
	dw $400
	dw $840a,$0,$9b5,$1180
	dw $8400,$110
	dw $840f,$171,$67b,$9b5,$8a6,$780
	dw $400
	dw $8407,$2e3,$0,$8a6,$1180
	dw $8400,$110
	dw $840b,$171,$67b,$9b5,$1180
	dw $401,$2e3
	dw $840b,$0,$0,$8a6,$110
	dw $8401,$171,$110
	dw $8407,$2e3,$67b,$0,$780
	dw $401,$0
	dw $8403,$171,$0,$1180
	dw $8401,$2e3,$110
	dw $840b,$0,$a49,$0,$110
	dw $400
	dw $8403,$171,$0,$1180
	dw $8400,$110
	dw $8407,$0,$b8c,$67b,$780
	dw $400
	dw $8407,$2e3,$0,$746,$780
	dw $8400,$780
	dw $840f,$114,$9b5,$7b5,$67b,$1180
	dw $401,$229
	dw $840b,$0,$0,$746,$110
	dw $8401,$114,$110
	dw $840b,$229,$9b5,$7b5,$780
	dw $401,$0
	dw $8407,$114,$0,$746,$1180
	dw $8401,$229,$110
	dw $8403,$0,$9b5,$110
	dw $400
	dw $840a,$0,$746,$1180
	dw $8400,$110
	dw $8407,$114,$9b5,$67b,$780
	dw $400
	dw $8403,$229,$0,$1180
	dw $8400,$110
	dw $840b,$114,$9b5,$67b,$1180
	dw $401,$229
	dw $8403,$0,$0,$110
	dw $8401,$114,$110
	dw $8407,$229,$9b5,$0,$780
	dw $401,$0
	dw $8403,$114,$0,$1180
	dw $8401,$229,$110
	dw $840b,$0,$a49,$0,$110
	dw $400
	dw $8403,$114,$0,$1180
	dw $8400,$110
	dw $8407,$0,$b8c,$67b,$780
	dw $400
	dw $8407,$229,$0,$746,$780
	dw $8400,$780
	dw $840f,$136,$9b5,$7b5,$67b,$1180
	dw $401,$26d
	dw $840b,$0,$0,$746,$110
	dw $8401,$136,$110
	dw $840b,$26d,$9b5,$7b5,$780
	dw $401,$0
	dw $8407,$136,$0,$8a6,$1180
	dw $8401,$26d,$110
	dw $8403,$0,$9b5,$110
	dw $400
	dw $840a,$0,$8a6,$1180
	dw $8400,$110
	dw $8407,$136,$9b5,$7b5,$780
	dw $400
	dw $8403,$26d,$0,$1180
	dw $8400,$110
	dw $840b,$136,$9b5,$7b5,$1180
	dw $401,$26d
	dw $8403,$0,$0,$110
	dw $8401,$136,$110
	dw $8407,$26d,$9b5,$746,$780
	dw $401,$0
	dw $8403,$136,$0,$780
	dw $8401,$26d,$780
	dw $840b,$0,$a49,$746,$780
	dw $400
	dw $403,$136,$0
	dw $400
	dw $407,$0,$b8c,$0
	dw $400
	dw $403,$26d,$0
	dw $400
	dw $840f,$19e,$9b5,$e8c,$0,$1180
	dw $400
	dw $8407,$33d,$0,$0,$110
	dw $8400,$110
	dw $840b,$19e,$9b5,$e8c,$780
	dw $400
	dw $840f,$33d,$0,$e8c,$0,$1180
	dw $8400,$110
	dw $8407,$171,$9b5,$0,$110
	dw $400
	dw $840b,$2e3,$0,$e8c,$1180
	dw $8400,$110
	dw $840f,$19e,$9b5,$f6a,$0,$780
	dw $400
	dw $8407,$33d,$0,$0,$1180
	dw $8400,$110
	dw $840b,$19e,$9b5,$f6a,$1180
	dw $400
	dw $840f,$33d,$0,$f6a,$0,$110
	dw $8400,$110
	dw $8407,$19e,$9b5,$0,$780
	dw $400
	dw $840b,$33d,$0,$f6a,$1180
	dw $8400,$110
	dw $840f,$149,$a49,$cf6,$0,$110
	dw $400
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $840b,$171,$b8c,$cf6,$780
	dw $400
	dw $840b,$2e3,$0,$0,$780
	dw $8400,$780
	dw $8407,$149,$67b,$e8c,$1180
	dw $400
	dw $8407,$292,$0,$0,$110
	dw $8400,$110
	dw $840b,$149,$67b,$e8c,$780
	dw $400
	dw $840f,$292,$0,$e8c,$0,$1180
	dw $8400,$110
	dw $8407,$136,$67b,$0,$110
	dw $400
	dw $840b,$26d,$0,$e8c,$1180
	dw $8400,$110
	dw $840f,$149,$67b,$f6a,$0,$780
	dw $400
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $840b,$149,$67b,$f6a,$1180
	dw $400
	dw $840f,$292,$0,$f6a,$0,$110
	dw $8400,$110
	dw $8407,$149,$67b,$0,$780
	dw $400
	dw $840b,$292,$0,$f6a,$1180
	dw $8400,$110
	dw $840f,$149,$a49,$cf6,$0,$110
	dw $400
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $840b,$171,$b8c,$cf6,$780
	dw $400
	dw $840b,$2e3,$0,$0,$780
	dw $8400,$780
	dw $8407,$19e,$9b5,$e8c,$1180
	dw $400
	dw $8407,$33d,$0,$0,$110
	dw $8400,$110
	dw $840b,$19e,$9b5,$e8c,$780
	dw $400
	dw $840f,$33d,$0,$e8c,$0,$1180
	dw $8400,$110
	dw $8407,$171,$9b5,$0,$110
	dw $400
	dw $840b,$2e3,$0,$e8c,$1180
	dw $8400,$110
	dw $840f,$19e,$9b5,$f6a,$0,$780
	dw $400
	dw $8407,$33d,$0,$0,$1180
	dw $8400,$110
	dw $840b,$19e,$9b5,$f6a,$1180
	dw $400
	dw $840f,$33d,$0,$f6a,$0,$110
	dw $8400,$110
	dw $8407,$19e,$9b5,$0,$780
	dw $400
	dw $840b,$33d,$0,$f6a,$1180
	dw $8400,$110
	dw $840f,$149,$a49,$cf6,$0,$110
	dw $400
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $840b,$171,$b8c,$cf6,$780
	dw $400
	dw $840b,$2e3,$0,$0,$780
	dw $8400,$780
	dw $8407,$114,$9b5,$e8c,$1180
	dw $400
	dw $8407,$229,$0,$0,$110
	dw $8400,$110
	dw $840b,$114,$9b5,$e8c,$780
	dw $400
	dw $840f,$229,$0,$e8c,$0,$1180
	dw $8400,$110
	dw $8407,$f6,$9b5,$0,$110
	dw $400
	dw $840b,$1ed,$0,$e8c,$1180
	dw $8400,$110
	dw $840f,$114,$9b5,$f6a,$0,$780
	dw $400
	dw $8407,$229,$0,$0,$1180
	dw $8400,$110
	dw $840b,$136,$9b5,$f6a,$1180
	dw $400
	dw $840f,$26d,$0,$f6a,$0,$110
	dw $8400,$110
	dw $8407,$136,$9b5,$0,$780
	dw $400
	dw $840b,$26d,$0,$f6a,$1180
	dw $8400,$110
	dw $840f,$149,$a49,$cf6,$0,$180
	dw $8400,$380
	dw $8407,$292,$0,$0,$580
	dw $8400,$780
	dw $840b,$171,$b8c,$cf6,$980
	dw $8400,$b80
	dw $840b,$2e3,$0,$0,$d80
	dw $8400,$f80
	dw $8407,$19e,$9b5,$e8c,$1180
	dw $8400,$110
	dw $8407,$33d,$0,$0,$180
	dw $8400,$1180
	dw $840b,$19e,$9b5,$e8c,$780
	dw $8400,$110
	dw $840f,$33d,$0,$e8c,$0,$1180
	dw $8400,$110
	dw $8407,$171,$9b5,$0,$180
	dw $8400,$110
	dw $840b,$2e3,$0,$e8c,$1180
	dw $8400,$110
	dw $840f,$19e,$9b5,$f6a,$0,$780
	dw $8400,$110
	dw $8407,$33d,$0,$0,$1180
	dw $8400,$110
	dw $840b,$19e,$9b5,$f6a,$1180
	dw $8400,$110
	dw $840f,$33d,$0,$f6a,$0,$180
	dw $8400,$1180
	dw $8407,$19e,$9b5,$0,$780
	dw $8400,$110
	dw $840b,$33d,$0,$f6a,$1180
	dw $8400,$110
	dw $840f,$149,$a49,$cf6,$0,$180
	dw $8400,$110
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $840b,$171,$b8c,$cf6,$780
	dw $8400,$110
	dw $840b,$2e3,$0,$0,$780
	dw $8400,$780
	dw $8407,$149,$67b,$e8c,$1180
	dw $8400,$110
	dw $8407,$292,$0,$0,$180
	dw $8400,$1180
	dw $840b,$149,$67b,$e8c,$780
	dw $8400,$110
	dw $840f,$292,$0,$e8c,$0,$1180
	dw $8400,$110
	dw $8407,$136,$67b,$0,$180
	dw $8400,$110
	dw $840b,$26d,$0,$e8c,$1180
	dw $8400,$110
	dw $840f,$149,$67b,$f6a,$0,$780
	dw $8400,$110
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $840b,$149,$67b,$f6a,$1180
	dw $8400,$110
	dw $840f,$292,$0,$f6a,$0,$180
	dw $8400,$1180
	dw $8407,$149,$67b,$0,$780
	dw $8400,$110
	dw $840b,$292,$0,$f6a,$1180
	dw $8400,$110
	dw $840f,$149,$a49,$cf6,$0,$780
	dw $8400,$780
	dw $8407,$292,$0,$0,$710
	dw $8400,$710
	dw $840b,$171,$b8c,$cf6,$780
	dw $8400,$780
	dw $840b,$2e3,$0,$0,$710
	dw $8400,$780
	dw $8407,$19e,$9b5,$e8c,$1180
	dw $8400,$110
	dw $8407,$33d,$0,$0,$180
	dw $8400,$1180
	dw $840b,$19e,$9b5,$e8c,$780
	dw $8400,$110
	dw $840f,$33d,$0,$e8c,$0,$1180
	dw $8400,$110
	dw $8407,$171,$9b5,$0,$180
	dw $8400,$110
	dw $840b,$2e3,$0,$e8c,$1180
	dw $8400,$110
	dw $840f,$19e,$9b5,$f6a,$0,$780
	dw $8400,$110
	dw $8407,$33d,$0,$0,$1180
	dw $8400,$110
	dw $840b,$19e,$9b5,$f6a,$1180
	dw $8400,$110
	dw $840f,$33d,$0,$f6a,$0,$180
	dw $8400,$1180
	dw $8407,$19e,$9b5,$0,$780
	dw $8400,$110
	dw $840b,$33d,$0,$f6a,$1180
	dw $8400,$110
	dw $840f,$149,$a49,$cf6,$0,$180
	dw $8400,$110
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $840b,$171,$b8c,$cf6,$780
	dw $8400,$110
	dw $840b,$2e3,$0,$0,$780
	dw $8400,$780
	dw $8407,$114,$9b5,$e8c,$1180
	dw $8400,$110
	dw $8407,$229,$0,$0,$180
	dw $8400,$1180
	dw $840b,$114,$9b5,$e8c,$780
	dw $8400,$110
	dw $840f,$229,$0,$e8c,$0,$1180
	dw $8400,$110
	dw $8407,$f6,$9b5,$0,$180
	dw $8400,$110
	dw $840b,$1ed,$0,$e8c,$1180
	dw $8400,$110
	dw $840f,$114,$9b5,$f6a,$0,$780
	dw $8400,$110
	dw $8407,$229,$0,$0,$1180
	dw $8400,$110
	dw $840b,$26d,$9b5,$f6a,$180
	dw $8400,$380
	dw $840e,$265,$f6a,$0,$180
	dw $8400,$380
	dw $8404,$0,$580
	dw $8400,$380
	dw $8408,$f6a,$580
	dw $8400,$780
	dw $840f,$292,$28a,$cf6,$0,$580
	dw $8400,$780
	dw $8404,$0,$980
	dw $8400,$780
	dw $840b,$2e3,$2d3,$cf6,$980
	dw $8400,$b80
	dw $8408,$0,$980
	dw $8400,$b80
	dw $8407,$19e,$0,$9b5,$1180
	dw $401,$33d
	dw $405,$0,$8a6
	dw $401,$19e
	dw $8409,$33d,$9b5,$110
	dw $401,$0
	dw $840d,$19e,$9b5,$8a6,$110
	dw $401,$33d
	dw $8405,$0,$8a6,$780
	dw $400
	dw $408,$9b5
	dw $400
	dw $840d,$19e,$9b5,$8a6,$110
	dw $400
	dw $8405,$33d,$8a6,$110
	dw $400
	dw $409,$19e,$9b5
	dw $401,$33d
	dw $409,$0,$8a6
	dw $401,$19e
	dw $8405,$33d,$0,$1180
	dw $401,$0
	dw $401,$19e
	dw $401,$33d
	dw $8409,$0,$0,$780
	dw $400
	dw $401,$19e
	dw $400
	dw $8401,$0,$110
	dw $400
	dw $8401,$33d,$110
	dw $400
	dw $8405,$171,$9b5,$1180
	dw $401,$2e3
	dw $405,$0,$8a6
	dw $401,$171
	dw $8409,$2e3,$9b5,$110
	dw $401,$0
	dw $840d,$171,$9b5,$8a6,$110
	dw $401,$2e3
	dw $8405,$0,$8a6,$780
	dw $400
	dw $408,$9b5
	dw $400
	dw $840d,$171,$9b5,$8a6,$110
	dw $400
	dw $8405,$2e3,$8a6,$110
	dw $400
	dw $409,$171,$9b5
	dw $401,$2e3
	dw $409,$0,$8a6
	dw $401,$171
	dw $8405,$2e3,$0,$1180
	dw $401,$0
	dw $401,$171
	dw $401,$2e3
	dw $8409,$0,$0,$780
	dw $400
	dw $401,$171
	dw $400
	dw $8405,$0,$67b,$110
	dw $400
	dw $8405,$2e3,$746,$110
	dw $400
	dw $840f,$114,$f6a,$7b5,$67b,$1180
	dw $403,$229,$0
	dw $40b,$0,$e8c,$746
	dw $403,$114,$0
	dw $840b,$229,$cf6,$7b5,$110
	dw $403,$0,$0
	dw $8407,$114,$b8c,$746,$110
	dw $403,$229,$0
	dw $8405,$0,$f6a,$780
	dw $404,$0
	dw $40c,$e8c,$746
	dw $404,$0
	dw $8407,$114,$cf6,$67b,$110
	dw $402,$0
	dw $8403,$229,$b8c,$110
	dw $402,$0
	dw $40b,$114,$f6a,$67b
	dw $403,$229,$0
	dw $403,$0,$e8c
	dw $403,$114,$0
	dw $8405,$229,$cf6,$1180
	dw $405,$0,$0
	dw $405,$114,$b8c
	dw $405,$229,$0
	dw $8409,$0,$f6a,$780
	dw $408,$0
	dw $409,$114,$e8c
	dw $408,$0
	dw $840d,$0,$67b,$cf6,$110
	dw $408,$0
	dw $840d,$229,$746,$b8c,$110
	dw $408,$0
	dw $840f,$136,$f6a,$7b5,$67b,$1180
	dw $403,$26d,$0
	dw $40b,$0,$f6a,$746
	dw $403,$136,$0
	dw $840b,$26d,$f6a,$7b5,$110
	dw $403,$0,$0
	dw $8407,$136,$114d,$8a6,$110
	dw $403,$26d,$0
	dw $8403,$0,$114d,$780
	dw $402,$0
	dw $40a,$114d,$8a6
	dw $402,$0
	dw $8407,$136,$136b,$7b5,$110
	dw $402,$0
	dw $8403,$26d,$136b,$110
	dw $402,$0
	dw $40b,$136,$136b,$7b5
	dw $403,$26d,$0
	dw $403,$0,$136b
	dw $403,$136,$0
	dw $8407,$26d,$136b,$746,$1180
	dw $403,$0,$0
	dw $403,$136,$136b
	dw $403,$26d,$0
	dw $840f,$136,$136b,$0,$746,$780
	dw $402,$0
	dw $402,$136b
	dw $402,$0
	dw $840a,$136b,$0,$110
	dw $402,$0
	dw $8402,$136b,$110
	dw $402,$0
	dw $840f,$19e,$9ad,$9b5,$0,$1180
	dw $401,$33d
	dw $8407,$0,$0,$8a6,$110
	dw $8401,$19e,$110
	dw $840b,$33d,$9ad,$9b5,$780
	dw $401,$0
	dw $840f,$19e,$0,$9b5,$8a6,$1180
	dw $8401,$33d,$110
	dw $8407,$0,$9b5,$8a6,$110
	dw $400
	dw $840a,$0,$9b5,$1180
	dw $8400,$110
	dw $840f,$19e,$9ad,$9b5,$8a6,$780
	dw $400
	dw $8407,$33d,$0,$8a6,$1180
	dw $8400,$110
	dw $840b,$19e,$9ad,$9b5,$1180
	dw $401,$33d
	dw $840b,$0,$0,$8a6,$110
	dw $8401,$19e,$110
	dw $8407,$33d,$9b5,$0,$780
	dw $401,$0
	dw $8403,$19e,$0,$1180
	dw $8401,$33d,$110
	dw $840b,$0,$a49,$0,$110
	dw $400
	dw $8403,$19e,$0,$1180
	dw $8400,$110
	dw $8403,$0,$b8c,$780
	dw $400
	dw $8403,$33d,$0,$780
	dw $8400,$780
	dw $8407,$171,$67b,$9b5,$1180
	dw $401,$2e3
	dw $8407,$0,$0,$8a6,$110
	dw $8401,$171,$110
	dw $840b,$2e3,$67b,$9b5,$780
	dw $401,$0
	dw $840f,$171,$0,$9b5,$8a6,$1180
	dw $8401,$2e3,$110
	dw $8407,$0,$67b,$8a6,$110
	dw $400
	dw $840a,$0,$9b5,$1180
	dw $8400,$110
	dw $840f,$171,$67b,$9b5,$8a6,$780
	dw $400
	dw $8407,$2e3,$0,$8a6,$1180
	dw $8400,$110
	dw $840b,$171,$67b,$9b5,$1180
	dw $401,$2e3
	dw $840b,$0,$0,$8a6,$110
	dw $8401,$171,$110
	dw $8407,$2e3,$67b,$0,$780
	dw $401,$0
	dw $8403,$171,$0,$1180
	dw $8401,$2e3,$110
	dw $840b,$0,$a49,$0,$110
	dw $400
	dw $8403,$171,$0,$1180
	dw $8400,$110
	dw $8407,$0,$b8c,$67b,$780
	dw $400
	dw $8407,$2e3,$0,$746,$780
	dw $8400,$780
	dw $840f,$114,$9b5,$7b5,$67b,$1180
	dw $401,$229
	dw $840b,$0,$0,$746,$110
	dw $8401,$114,$110
	dw $840b,$229,$9b5,$7b5,$780
	dw $401,$0
	dw $8407,$114,$0,$746,$1180
	dw $8401,$229,$110
	dw $8403,$0,$9b5,$110
	dw $400
	dw $840a,$0,$746,$1180
	dw $8400,$110
	dw $8407,$114,$9b5,$67b,$780
	dw $400
	dw $8403,$229,$0,$1180
	dw $8400,$110
	dw $840b,$114,$9b5,$67b,$1180
	dw $401,$229
	dw $8403,$0,$0,$110
	dw $8401,$114,$110
	dw $8407,$229,$9b5,$0,$780
	dw $401,$0
	dw $8403,$114,$0,$1180
	dw $8401,$229,$110
	dw $840b,$0,$a49,$0,$110
	dw $400
	dw $8403,$114,$0,$1180
	dw $8400,$110
	dw $8407,$0,$b8c,$67b,$780
	dw $400
	dw $8407,$229,$0,$746,$780
	dw $8400,$780
	dw $840f,$136,$9b5,$7b5,$67b,$1180
	dw $401,$26d
	dw $840b,$0,$0,$746,$110
	dw $8401,$136,$110
	dw $840b,$26d,$9b5,$7b5,$780
	dw $401,$0
	dw $8407,$136,$0,$8a6,$1180
	dw $8401,$26d,$110
	dw $8403,$0,$9b5,$110
	dw $400
	dw $840a,$0,$8a6,$1180
	dw $8400,$110
	dw $8407,$136,$9b5,$7b5,$780
	dw $400
	dw $8403,$26d,$0,$1180
	dw $8400,$110
	dw $840b,$136,$9b5,$7b5,$1180
	dw $401,$26d
	dw $8403,$0,$0,$110
	dw $8401,$136,$110
	dw $8407,$26d,$9b5,$746,$780
	dw $401,$0
	dw $8403,$136,$0,$780
	dw $8401,$26d,$780
	dw $840b,$0,$a49,$746,$780
	dw $400
	dw $403,$136,$0
	dw $400
	dw $407,$0,$b8c,$0
	dw $400
	dw $403,$26d,$0
	dw $400
	dw $840f,$19e,$9b5,$73e,$746,$1180
	dw $400
	dw $8403,$33d,$0,$110
	dw $8400,$110
	dw $8403,$19e,$9b5,$780
	dw $400
	dw $8403,$33d,$0,$1180
	dw $8400,$110
	dw $8407,$171,$9b5,$73e,$120
	dw $404,$0
	dw $8407,$2e3,$0,$73e,$1180
	dw $8404,$0,$120
	dw $8407,$19e,$9b5,$73e,$780
	dw $404,$0
	dw $8407,$33d,$0,$73e,$1180
	dw $8404,$0,$120
	dw $8407,$19e,$9b5,$73e,$1180
	dw $400
	dw $8407,$33d,$0,$0,$140
	dw $8400,$140
	dw $8407,$19e,$9b5,$73e,$780
	dw $400
	dw $8407,$33d,$0,$0,$1180
	dw $8400,$140
	dw $8407,$149,$a49,$73e,$140
	dw $400
	dw $8407,$292,$0,$0,$1180
	dw $8400,$140
	dw $8407,$171,$b8c,$73e,$780
	dw $400
	dw $8407,$2e3,$0,$0,$780
	dw $8400,$780
	dw $840f,$149,$67b,$736,$746,$1180
	dw $400
	dw $8403,$292,$0,$180
	dw $8400,$180
	dw $8403,$149,$67b,$780
	dw $400
	dw $8403,$292,$0,$1180
	dw $8400,$180
	dw $8407,$136,$67b,$736,$140
	dw $404,$0
	dw $8407,$26d,$0,$736,$1180
	dw $8404,$0,$140
	dw $8407,$149,$67b,$736,$780
	dw $404,$0
	dw $8407,$292,$0,$736,$1180
	dw $8404,$0,$140
	dw $8407,$149,$67b,$736,$1180
	dw $400
	dw $8407,$292,$0,$0,$120
	dw $8400,$120
	dw $8407,$149,$67b,$736,$780
	dw $400
	dw $8407,$292,$0,$0,$1180
	dw $8400,$120
	dw $8407,$149,$a49,$736,$110
	dw $400
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $8407,$171,$b8c,$736,$780
	dw $400
	dw $8407,$2e3,$0,$0,$780
	dw $8400,$780
	dw $840f,$19e,$9b5,$72e,$746,$1180
	dw $400
	dw $8403,$33d,$0,$120
	dw $8400,$120
	dw $8403,$19e,$9b5,$780
	dw $400
	dw $8403,$33d,$0,$1180
	dw $8400,$120
	dw $8407,$171,$9b5,$72e,$320
	dw $404,$0
	dw $8407,$2e3,$0,$72e,$1180
	dw $8404,$0,$320
	dw $8407,$19e,$9b5,$72e,$780
	dw $404,$0
	dw $8407,$33d,$0,$72e,$1180
	dw $8404,$0,$320
	dw $8407,$19e,$9b5,$72e,$1180
	dw $400
	dw $8407,$33d,$0,$0,$520
	dw $8400,$520
	dw $8407,$19e,$9b5,$72e,$780
	dw $400
	dw $8407,$33d,$0,$0,$1180
	dw $8400,$520
	dw $8407,$149,$a49,$72e,$110
	dw $400
	dw $8407,$292,$0,$0,$1180
	dw $8400,$720
	dw $8407,$171,$b8c,$72e,$780
	dw $400
	dw $8407,$2e3,$0,$0,$780
	dw $8400,$780
	dw $840f,$114,$9b5,$726,$746,$1180
	dw $400
	dw $8403,$229,$0,$720
	dw $8400,$720
	dw $8403,$114,$9b5,$780
	dw $400
	dw $8403,$229,$0,$1180
	dw $8400,$720
	dw $8407,$f6,$9b5,$726,$520
	dw $404,$0
	dw $8407,$1ed,$0,$726,$1180
	dw $8404,$0,$520
	dw $8407,$114,$9b5,$726,$780
	dw $404,$0
	dw $8407,$229,$0,$726,$1180
	dw $8404,$0,$520
	dw $8407,$136,$9b5,$726,$1180
	dw $400
	dw $8407,$26d,$0,$0,$320
	dw $8400,$320
	dw $8407,$136,$9b5,$726,$780
	dw $400
	dw $8407,$26d,$0,$0,$1180
	dw $8400,$110
	dw $8407,$149,$a49,$726,$180
	dw $8400,$380
	dw $8407,$292,$0,$0,$580
	dw $8400,$780
	dw $8407,$171,$b8c,$726,$980
	dw $8400,$b80
	dw $8407,$2e3,$0,$0,$d80
	dw $8400,$f80
	dw $840f,$19e,$9b5,$e8c,$746,$1180
	dw $8400,$110
	dw $8407,$33d,$0,$73e,$180
	dw $8400,$1180
	dw $8403,$19e,$9b5,$780
	dw $8400,$110
	dw $8407,$33d,$0,$e8c,$1180
	dw $8400,$110
	dw $8407,$171,$9b5,$73e,$180
	dw $8404,$0,$110
	dw $8407,$2e3,$0,$73e,$1180
	dw $8404,$0,$110
	dw $8407,$19e,$9b5,$f6a,$780
	dw $8400,$110
	dw $8407,$33d,$0,$73e,$1180
	dw $8404,$0,$110
	dw $8407,$19e,$9b5,$73e,$1180
	dw $8404,$0,$110
	dw $8407,$33d,$0,$f6a,$180
	dw $8400,$1180
	dw $8407,$19e,$9b5,$73e,$780
	dw $8400,$110
	dw $8407,$33d,$0,$0,$1180
	dw $8400,$110
	dw $8407,$149,$a49,$cf6,$180
	dw $8400,$110
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $8407,$171,$b8c,$73e,$780
	dw $8400,$110
	dw $8407,$2e3,$0,$0,$780
	dw $8400,$780
	dw $840f,$149,$67b,$e8c,$746,$1180
	dw $8400,$110
	dw $8407,$292,$0,$736,$180
	dw $8400,$1180
	dw $8403,$149,$67b,$780
	dw $8400,$110
	dw $8407,$292,$0,$e8c,$1180
	dw $8400,$110
	dw $8407,$136,$67b,$736,$180
	dw $8404,$0,$110
	dw $8407,$26d,$0,$746,$1180
	dw $8404,$0,$110
	dw $8407,$149,$67b,$f6a,$780
	dw $8400,$110
	dw $8407,$292,$0,$736,$1180
	dw $8404,$0,$110
	dw $8407,$149,$67b,$746,$1180
	dw $8404,$0,$110
	dw $8407,$292,$0,$f6a,$180
	dw $8400,$1180
	dw $8407,$149,$67b,$736,$780
	dw $8400,$110
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $8407,$149,$a49,$cf6,$780
	dw $8400,$780
	dw $8407,$292,$0,$0,$710
	dw $8400,$710
	dw $8407,$171,$b8c,$736,$780
	dw $8400,$780
	dw $8407,$2e3,$0,$0,$710
	dw $8400,$780
	dw $840f,$19e,$9b5,$e8c,$746,$1180
	dw $8400,$110
	dw $8407,$33d,$0,$72e,$180
	dw $8400,$1180
	dw $8403,$19e,$9b5,$780
	dw $8400,$110
	dw $8407,$33d,$0,$e8c,$1180
	dw $8400,$110
	dw $8407,$171,$9b5,$72e,$180
	dw $8404,$0,$110
	dw $8407,$2e3,$0,$72e,$1180
	dw $8404,$0,$110
	dw $8407,$19e,$9b5,$f6a,$780
	dw $8400,$110
	dw $8407,$33d,$0,$72e,$1180
	dw $8404,$0,$110
	dw $8407,$19e,$9b5,$72e,$1180
	dw $8404,$0,$110
	dw $8407,$33d,$0,$f6a,$180
	dw $8400,$1180
	dw $8407,$19e,$9b5,$72e,$780
	dw $8400,$110
	dw $8407,$33d,$0,$0,$1180
	dw $8400,$110
	dw $8407,$149,$a49,$cf6,$180
	dw $8400,$110
	dw $8407,$292,$0,$0,$1180
	dw $8400,$110
	dw $8407,$171,$b8c,$72e,$780
	dw $8400,$110
	dw $8407,$2e3,$0,$0,$780
	dw $8400,$780
	dw $840f,$114,$9b5,$e8c,$746,$1180
	dw $8400,$110
	dw $8407,$229,$0,$726,$180
	dw $8400,$1180
	dw $8403,$114,$9b5,$780
	dw $8400,$110
	dw $8407,$229,$0,$e8c,$1180
	dw $8400,$110
	dw $8407,$f6,$9b5,$726,$180
	dw $8404,$0,$110
	dw $8407,$1ed,$0,$726,$1180
	dw $8404,$0,$110
	dw $8407,$114,$9b5,$f6a,$780
	dw $8400,$110
	dw $8407,$229,$0,$726,$1180
	dw $8404,$0,$110
	dw $8407,$136,$9b5,$726,$180
	dw $8404,$0,$380
	dw $8407,$26d,$0,$f6a,$180
	dw $8400,$380
	dw $8405,$136,$726,$580
	dw $8400,$380
	dw $8405,$26d,$0,$580
	dw $8400,$780
	dw $840d,$149,$cf6,$0,$580
	dw $8400,$780
	dw $8405,$292,$0,$980
	dw $8400,$780
	dw $8401,$171,$980
	dw $8400,$b80
	dw $8401,$2e3,$980
	dw $8400,$b80
	dw $8403,$19e,$9b5,$1180
	dw $400
	dw $8403,$0,$0,$110
	dw $8400,$110
	dw $8403,$19e,$9b5,$780
	dw $400
	dw $8403,$33d,$0,$1180
	dw $8400,$110
	dw $8403,$171,$9b5,$110
	dw $400
	dw $8403,$2e3,$0,$1180
	dw $8400,$110
	dw $8403,$19e,$9b5,$780
	dw $400
	dw $8403,$33d,$0,$1180
	dw $8400,$110
	dw $8403,$19e,$9b5,$1180
	dw $400
	dw $8403,$0,$0,$110
	dw $8400,$110
	dw $8403,$19e,$9b5,$780
	dw $400
	dw $8403,$33d,$0,$1180
	dw $8400,$110
	dw $8403,$149,$a49,$780
	dw $8400,$780
	dw $8403,$292,$0,$1180
	dw $8400,$1180
	dw $8403,$171,$b8c,$780
	dw $8400,$780
	dw $8403,$2e3,$0,$1180
	dw $8400,$1180
	dw $8403,$149,$67b,$1180
	dw $400
	dw $8403,$0,$0,$110
	dw $8400,$110
	dw $8403,$149,$67b,$780
	dw $400
	dw $8403,$292,$0,$1180
	dw $8400,$110
	dw $8403,$136,$67b,$110
	dw $400
	dw $8403,$26d,$0,$1180
	dw $8400,$110
	dw $8403,$149,$67b,$780
	dw $400
	dw $8403,$292,$0,$1180
	dw $8400,$110
	dw $8403,$149,$67b,$1180
	dw $400
	dw $8403,$0,$0,$110
	dw $8400,$1180
	dw $8403,$149,$67b,$780
	dw $400
	dw $8403,$292,$0,$1180
	dw $8400,$1180
	dw $8403,$149,$a49,$780
	dw $400
	dw $8403,$292,$0,$1180
	dw $8400,$1180
	dw $8403,$171,$b8c,$780
	dw $400
	dw $8403,$2e3,$0,$780
	dw $8400,$780
	dw $8403,$19e,$9b5,$1180
	dw $400
	dw $8403,$0,$0,$110
	dw $8400,$110
	dw $8403,$19e,$9b5,$780
	dw $400
	dw $8403,$33d,$0,$1180
	dw $8400,$110
	dw $8403,$171,$9b5,$110
	dw $400
	dw $8403,$2e3,$0,$1180
	dw $8400,$110
	dw $8403,$19e,$9b5,$780
	dw $400
	dw $8403,$33d,$0,$1180
	dw $8400,$110
	dw $8403,$19e,$9b5,$1180
	dw $400
	dw $8403,$0,$0,$110
	dw $8400,$110
	dw $8403,$19e,$9b5,$780
	dw $400
	dw $8403,$33d,$0,$1180
	dw $8400,$110
	dw $8403,$149,$a49,$780
	dw $8400,$780
	dw $8403,$292,$0,$1180
	dw $8400,$1180
	dw $8403,$171,$b8c,$780
	dw $8400,$780
	dw $8403,$2e3,$0,$1180
	dw $8400,$1180
	dw $8403,$114,$9b5,$1180
	dw $400
	dw $8403,$0,$0,$110
	dw $8400,$110
	dw $8403,$114,$9b5,$780
	dw $400
	dw $8403,$229,$0,$1180
	dw $8400,$110
	dw $8403,$f6,$9b5,$110
	dw $400
	dw $8403,$1ed,$0,$1180
	dw $8400,$110
	dw $8403,$114,$9b5,$780
	dw $400
	dw $8403,$229,$0,$1180
	dw $8400,$110
	dw $8403,$136,$9b5,$180
	dw $8400,$380
	dw $8403,$0,$0,$180
	dw $8400,$380
	dw $8403,$136,$9b5,$580
	dw $8400,$380
	dw $8403,$26d,$0,$580
	dw $8400,$780
	dw $8403,$149,$a49,$580
	dw $8400,$780
	dw $8403,$292,$0,$980
	dw $8400,$780
	dw $8403,$171,$b8c,$980
	dw $8400,$b80
	dw $8403,$2e3,$0,$980
	dw $8400,$b80
	dw $8403,$19e,$196,$780
	dw $400
	dw $8400,$740
	dw $400
	dw $8400,$720
	dw $400
	dw $8400,$710
	dw $400
	dw $402,$0
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $401,$0
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
.loop:
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw $400
	dw 0


music_data2:

END _asm

AUTORUN:

	REM 'ϱӱױ'
	CLS
	PRINT AT 3,0;"ϱ"
	PRINT AT 6,0;" SQUAT",," SHIRU, 06/17"
	PRINT AT 11,3;"MUSIC: STANDING WAVE";TAB 3;"AUTHOR: SHIRU, 01/21"
	PRINT AT 16,1;"TYPE ANY KEY TO HEAR THE MUSIC"
	PRINT AT 19,0;""
.waitk:
	IF INKEY$="" THEN GOTO #.waitk#
	RAND USR #start
	GOTO #.waitk#


	include 'SINCL-ZX\ZX81DISP.INC' 	 ; include D_FILE and needed memory areas

VARS_ADDR:
	db 80h

WORKSPACE:

assert ($-MEMST)<MEMAVL
// end of program
